@@ -1,10 +1,17 @@
 /*
  * Copyright 1999 (c) Adrian Sun (asun@u.washington.edu)
  * All Rights Reserved. See COPYRIGHT.
+ */
+
+/*!
+ * @file
+ * @brief AFP user password utility
  *
  * format of the password file:
+ * @code
  * name:****************:****************:********
  *      password         last login date  failed usage count
+ * @endcode
  *
  * ***'s are illegal. they're just place holders for hex values. hex
  * values that represent actual numbers are in network byte order.
@@ -14,8 +21,10 @@
  *
  * the last two fields aren't currently used by the randnum uams.
  *
+ * @code
  * root syntax: afppasswd [-c] [-a] [-p path] [-f] [username]
  * user syntax: afppasswd
+ * @endcode
  */
 
 #ifdef HAVE_CONFIG_H
@@ -104,7 +113,7 @@ static void convert_passwd(char *buf, char *newpwd, const int keyfd)
 
         ctxerror = gcry_cipher_open(&ctx, GCRY_CIPHER_DES, GCRY_CIPHER_MODE_ECB, 0);
         ctxerror = gcry_cipher_setkey(ctx, key, DES_KEY_SZ);
-        memset(key, 0, sizeof(key));
+        explicit_bzero(key, sizeof(key));
 
         if (newpwd) {
             ctxerror = gcry_cipher_encrypt(ctx, newpwd, DES_KEY_SZ, NULL, 0);
