@@ -14,10 +14,10 @@
 #include <sys/file.h>
 #include <sys/param.h>
 
+#include <bstrlib.h>
+
 #include <atalk/adouble.h>
 #include <atalk/afp.h>
-#include <atalk/bstradd.h>
-#include <atalk/bstrlib.h>
 #include <atalk/cnid.h>
 #include <atalk/globals.h>
 #include <atalk/logger.h>
@@ -35,9 +35,9 @@
 
 #define min(a,b)	((a)<(b)?(a):(b))
 
-/*
- * Struct to save directory reading context in. Used to prevent
- * O(n^2) searches on a directory.
+/*!
+ * @brief Struct to save directory reading context in.
+ * @note Used to prevent O(n^2) searches on a directory.
  */
 struct savedir {
     u_short	 sd_vid;
@@ -52,69 +52,79 @@ struct savedir {
 static int enumerate_loop(struct dirent *de, char *mname _U_, void *data)
 {
     struct savedir *sd = data;
-    char *start, *end;
-    int  len,lenm;
-
+    char *start;
+    const char *end;
+    int len;
+    int bytes_needed;
     end = sd->sd_buf + sd->sd_buflen;
-    len = strlen(de->d_name);
+    len = (int) strnlen(de->d_name, UTF8FILELEN_EARLY);
+    bytes_needed = 1 + len + 1;
     *(sd->sd_last)++ = len;
-    lenm = 0; /* strlen(mname);*/
-    if ( sd->sd_last + len +lenm + 4 > end ) {
+
+    if (sd->sd_last + bytes_needed > end) {
+        start = sd->sd_buf;
         char *buf;
 
-        start = sd->sd_buf;
-        if (!(buf = realloc( sd->sd_buf, sd->sd_buflen +SDBUFBRK )) ) {
+        if (!(buf = realloc(sd->sd_buf, sd->sd_buflen + SDBUFBRK))) {
             LOG(log_error, logtype_afpd, "afp_enumerate: realloc: %s",
-                        strerror(errno) );
+                strerror(errno));
+            /* Restore position to avoid invalid data */
+            sd->sd_last--;
             errno = ENOMEM;
             return -1;
         }
+
         sd->sd_buf = buf;
         sd->sd_buflen += SDBUFBRK;
-        sd->sd_last = ( sd->sd_last - start ) + sd->sd_buf;
+        sd->sd_last = (sd->sd_last - start) + sd->sd_buf;
         end = sd->sd_buf + sd->sd_buflen;
     }
 
-    memcpy( sd->sd_last, de->d_name, len + 1 );
+    memcpy(sd->sd_last, de->d_name, len + 1);
     sd->sd_last += len + 1;
     return 0;
 }
 
-/* -----------------------------
- * FIXME:
+/*!
+ * @bug
  * Doesn't work with dangling symlink
  * i.e.:
  * - Move a folder with a dangling symlink in the trash
  * - empty the trash
+ *
  * afp_enumerate return an empty listing but offspring count != 0 in afp_getdirparams
  * and the Mac doesn't try to call afp_delete!
  *
- * Another option for symlink
- * cf:
- * http://sourceforge.net/tracker/index.php?func=detail&aid=461938&group_id=8642&atid=108642
+ * @sa https://sourceforge.net/p/netatalk/bugs/97/
  *
 */
 char *check_dirent(const struct vol *vol, char *name)
 {
-    if (!strcmp(name, "..") || !strcmp(name, "."))
+    if (!strcmp(name, "..") || !strcmp(name, ".")) {
         return NULL;
+    }
 
-    if (!vol->vfs->vfs_validupath(vol, name))
+    if (!vol->vfs->vfs_validupath(vol, name)) {
         return NULL;
+    }
 
     /* check for vetoed filenames */
-    if (veto_file(vol->v_veto, name))
+    if (veto_file(vol->v_veto, name)) {
         return NULL;
+    }
 
 #if 0
     char *m_name = NULL;
 
-    if (NULL == (m_name = utompath(vol, name, 0, utf8_encoding())))
+    if (NULL == (m_name = utompath(vol, name, 0, utf8_encoding()))) {
         return NULL;
+    }
 
     /* now check against too big a file */
-    if (strlen(m_name) > vol->max_filename)
+    if (strlen(m_name) > vol->max_filename) {
         return NULL;
+    }
+
 #endif
     return name;
 }
@@ -128,25 +138,30 @@ for_each_dirent(const struct vol *vol, char *name, dir_loop fn, void *data)
     char            *m_name;
     int             ret;
 
-    if (NULL == ( dp = opendir( name)) ) {
+    if (NULL == (dp = opendir(name))) {
         return -1;
     }
+
     ret = 0;
-    for ( de = readdir( dp ); de != NULL; de = readdir( dp )) {
-        if (!(m_name = check_dirent(vol, de->d_name)))
+
+    for (de = readdir(dp); de != NULL; de = readdir(dp)) {
+        if (!(m_name = check_dirent(vol, de->d_name))) {
             continue;
+        }
 
         ret++;
-        if (fn && fn(de,m_name, data) < 0) {
-           closedir(dp);
-           return -1;
+
+        if (fn && fn(de, m_name, data) < 0) {
+            closedir(dp);
+            return -1;
         }
     }
+
     closedir(dp);
     return ret;
 }
 
-/* This is the maximal length of a single entry for a file/dir in the reply
+/*! This is the maximal length of a single entry for a file/dir in the reply
    block if all bits in the file/dir bitmap are set: header(4) + params(104) +
    macnamelength(1) + macname(31) + utf8(4) + utf8namelen(2) + utf8name(255) +
    oddpadding(1) */
@@ -155,9 +170,7 @@ for_each_dirent(const struct vol *vol, char *name, dir_loop fn, void *data)
 
 /* ----------------------------- */
 static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
-    char *rbuf,
-    size_t *rbuflen,
-    int ext)
+                     char *rbuf, size_t *rbuflen, int ext)
 {
     static struct savedir	sd = { 0, 0, 0, NULL, NULL, 0 };
     struct vol			*vol;
@@ -172,63 +185,63 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
     struct path                 s_path;
     int                         header;
 
-    if ( sd.sd_buflen == 0 ) {
-        if (( sd.sd_buf = (char *)malloc( SDBUFBRK )) == NULL ) {
-            LOG(log_error, logtype_afpd, "afp_enumerate: malloc: %s", strerror(errno) );
+    if (sd.sd_buflen == 0) {
+        if ((sd.sd_buf = (char *)malloc(SDBUFBRK)) == NULL) {
+            LOG(log_error, logtype_afpd, "afp_enumerate: malloc: %s", strerror(errno));
             *rbuflen = 0;
             return AFPERR_MISC;
         }
+
         sd.sd_buflen = SDBUFBRK;
     }
 
     ibuf += 2;
+    memcpy(&vid, ibuf, sizeof(vid));
+    ibuf += sizeof(vid);
 
-    memcpy( &vid, ibuf, sizeof( vid ));
-    ibuf += sizeof( vid );
-
-    if (NULL == ( vol = getvolbyvid( vid )) ) {
+    if (NULL == (vol = getvolbyvid(vid))) {
         *rbuflen = 0;
-        return( AFPERR_PARAM );
+        return AFPERR_PARAM;
     }
 
-    memcpy( &did, ibuf, sizeof( did ));
-    ibuf += sizeof( did );
+    memcpy(&did, ibuf, sizeof(did));
+    ibuf += sizeof(did);
 
-    if (NULL == ( dir = dirlookup( vol, did )) ) {
+    if (NULL == (dir = dirlookup(vol, did))) {
         *rbuflen = 0;
-        return (afp_errno == AFPERR_NOOBJ)?AFPERR_NODIR:afp_errno;
+        return (afp_errno == AFPERR_NOOBJ) ? AFPERR_NODIR : afp_errno;
     }
 
-    memcpy( &fbitmap, ibuf, sizeof( fbitmap ));
-    fbitmap = ntohs( fbitmap );
-    ibuf += sizeof( fbitmap );
-
-    memcpy( &dbitmap, ibuf, sizeof( dbitmap ));
-    dbitmap = ntohs( dbitmap );
-    ibuf += sizeof( dbitmap );
+    memcpy(&fbitmap, ibuf, sizeof(fbitmap));
+    fbitmap = ntohs(fbitmap);
+    ibuf += sizeof(fbitmap);
+    memcpy(&dbitmap, ibuf, sizeof(dbitmap));
+    dbitmap = ntohs(dbitmap);
+    ibuf += sizeof(dbitmap);
 
     /* check for proper bitmaps -- the stuff in comments is for
      * variable directory ids. */
-    if (!(fbitmap || dbitmap)
-            /*|| (fbitmap & (1 << FILPBIT_PDID)) ||
-              (dbitmap & (1 << DIRPBIT_PDID))*/) {
+    if (!(fbitmap || dbitmap)) {
+#if 0
+        || (fbitmap & (1 << FILPBIT_PDID)) ||
+        (dbitmap & (1 << DIRPBIT_PDID))
+#endif
         *rbuflen = 0;
         return AFPERR_BITMAP;
     }
 
-    memcpy( &reqcnt, ibuf, sizeof( reqcnt ));
-    reqcnt = ntohs( reqcnt );
-    ibuf += sizeof( reqcnt );
+    memcpy(&reqcnt, ibuf, sizeof(reqcnt));
+    reqcnt = ntohs(reqcnt);
+    ibuf += sizeof(reqcnt);
 
     if (ext == 2) {
-        memcpy( &sindex, ibuf, sizeof( sindex ));
-        sindex = ntohl( sindex );
-        ibuf += sizeof( sindex );
-    }
-    else {
-        memcpy( &temp16, ibuf, sizeof( temp16 ));
-        sindex = ntohs( temp16 );
-        ibuf += sizeof( temp16 );
+        memcpy(&sindex, ibuf, sizeof(sindex));
+        sindex = ntohl(sindex);
+        ibuf += sizeof(sindex);
+    } else {
+        memcpy(&temp16, ibuf, sizeof(temp16));
+        sindex = ntohs(temp16);
+        ibuf += sizeof(temp16);
     }
 
     if (!sindex) {
@@ -237,69 +250,74 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
     }
 
     if (ext == 2) {
-        memcpy( &maxsz, ibuf, sizeof( maxsz ));
-        maxsz = ntohl( maxsz );
-        ibuf += sizeof( maxsz );
-    }
-    else {
-        memcpy( &temp16, ibuf, sizeof( temp16 ));
-        maxsz = ntohs( temp16 );
-        ibuf += sizeof( temp16 );
+        memcpy(&maxsz, ibuf, sizeof(maxsz));
+        maxsz = ntohl(maxsz);
+        ibuf += sizeof(maxsz);
+    } else {
+        memcpy(&temp16, ibuf, sizeof(temp16));
+        maxsz = ntohs(temp16);
+        ibuf += sizeof(temp16);
     }
 
-    header = (ext)?4:2;
-    header *=sizeof( u_char );
-
+    header = ext ? 4 : 2;
+    header *= sizeof(uint8_t);
     maxsz = min(maxsz, *rbuflen - REPLY_PARAM_MAXLEN);
-    o_path = cname( vol, dir, &ibuf );
+    o_path = cname(vol, dir, &ibuf);
 
-    if (afp_errno == AFPERR_NOOBJ)
+    if (afp_errno == AFPERR_NOOBJ) {
         afp_errno = AFPERR_NODIR;
+    }
 
     *rbuflen = 0;
-    if (NULL == o_path ) {
+
+    if (NULL == o_path) {
         return get_afp_errno(AFPERR_NOOBJ);
     }
-    if ( *o_path->m_name != '\0') {
+
+    if (*o_path->m_name != '\0') {
         /* it's a file or it's a dir and extendir() was unable to chdir in it */
-        return path_error(o_path, AFPERR_NODIR );
+        return path_error(o_path, AFPERR_NODIR);
     }
 
-    LOG(log_debug, logtype_afpd, "enumerate(\"%s/%s\", f/d:%04x/%04x, rc:%u, i:%u, max:%u)",
+    LOG(log_debug, logtype_afpd,
+        "enumerate(\"%s/%s\", f/d:%04x/%04x, rc:%u, i:%u, max:%u)",
         getcwdpath(), o_path->u_name, fbitmap, dbitmap, reqcnt, sindex, maxsz);
-
-    data = rbuf + 3 * sizeof( uint16_t );
-    sz = 3 * sizeof( uint16_t );	/* fbitmap, dbitmap, reqcount */
+    data = rbuf + 3 * sizeof(uint16_t);
+    sz = 3 * sizeof(uint16_t);	/* fbitmap, dbitmap, reqcount */
 
     /*
      * Read the directory into a pre-malloced buffer, stored
      *		len <name> \0
      * The end is indicated by a len of 0.
      */
-    if ( sindex == 1 || curdir->d_did != sd.sd_did || vid != sd.sd_vid ) {
+    if (sindex == 1 || curdir->d_did != sd.sd_did || vid != sd.sd_vid) {
         sd.sd_last = sd.sd_buf;
+
         /* if dir was in the cache we don't have the inode */
-        if (( !o_path->st_valid && ostat(".", &o_path->st, vol_syml_opt(vol)) < 0 ) ||
-            (ret = for_each_dirent(vol, ".", enumerate_loop, (void *)&sd)) < 0)
-        {
-            LOG(log_error, logtype_afpd, "enumerate: loop error: %s (%d)", strerror(errno), errno);
+        if ((!o_path->st_valid && ostat(".", &o_path->st, vol_syml_opt(vol)) < 0) ||
+                (ret = for_each_dirent(vol, ".", enumerate_loop, (void *)&sd)) < 0) {
+            LOG(log_error, logtype_afpd, "enumerate: loop error: %s (%d)", strerror(errno),
+                errno);
+
             switch (errno) {
             case EACCES:
                 return AFPERR_ACCESS;
+
             case ENOTDIR:
                 return AFPERR_BADTYPE;
+
             case ENOMEM:
                 return AFPERR_MISC;
+
             default:
                 return AFPERR_NODIR;
             }
         }
+
         setdiroffcnt(curdir, &o_path->st,  ret);
         *sd.sd_last = 0;
-
         sd.sd_last = sd.sd_buf;
         sd.sd_sindex = 1;
-
         sd.sd_vid = vid;
         sd.sd_did = curdir->d_did;
     }
@@ -307,25 +325,33 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
     /*
      * Position sd_last as dictated by sindex.
      */
-    if ( sindex < sd.sd_sindex ) {
+    if (sindex < sd.sd_sindex) {
         sd.sd_sindex = 1;
         sd.sd_last = sd.sd_buf;
     }
-    while ( sd.sd_sindex < sindex ) {
-        len = (unsigned char)*(sd.sd_last)++;
-        if ( len == 0 ) {
-            sd.sd_did = 0;	/* invalidate sd struct to force re-read */
-            return( AFPERR_NOOBJ );
+
+    while (sd.sd_sindex < sindex) {
+        if (sd.sd_last == NULL) {
+            sd.sd_did = 0;
+            return AFPERR_MISC;
         }
+
+        len = (unsigned char) * (sd.sd_last)++;
+
+        if (len == 0) {
+            sd.sd_did = 0;	/* invalidate sd struct to force re-read */
+            return AFPERR_NOOBJ;
+        }
+
         sd.sd_last += len + 1;
         sd.sd_sindex++;
     }
 
-    while (( len = (unsigned char)*(sd.sd_last)) != 0 ) {
+    while ((len = (unsigned char) * (sd.sd_last)) != 0) {
         /*
          * If we've got all we need, send it.
          */
-        if ( actcnt == reqcnt ) {
+        if (actcnt == reqcnt) {
             break;
         }
 
@@ -344,7 +370,8 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
 
         memset(&s_path, 0, sizeof(s_path));
         s_path.u_name = sd.sd_last;
-        if (of_stat(vol, &s_path) < 0 ) {
+
+        if (of_stat(vol, &s_path) < 0) {
             /* so the next time it won't try to stat it again
              * another solution would be to invalidate the cache with
              * sd.sd_did = 0 but if it's not ENOENT error it will start again
@@ -357,18 +384,25 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
 
         /* conversions on the fly */
         const char *convname;
+
         if (ad_convert(sd.sd_last, &s_path.st, vol, &convname) == 0) {
             if (convname) {
                 s_path.u_name = (char *)convname;
                 AFP_CNID_START("cnid_lookup");
-                s_path.id = cnid_lookup(vol->v_cdb, &s_path.st, curdir->d_did, sd.sd_last, strlen(sd.sd_last));
+                s_path.id = cnid_lookup(vol->v_cdb, &s_path.st, curdir->d_did, sd.sd_last,
+                                        strlen(sd.sd_last));
                 AFP_CNID_DONE();
+
                 if (s_path.id != CNID_INVALID) {
                     AFP_CNID_START("cnid_update");
-                    int cnid_up_ret = cnid_update(vol->v_cdb, s_path.id, &s_path.st, curdir->d_did, (char *)convname, strlen(convname));
+                    int cnid_up_ret = cnid_update(vol->v_cdb, s_path.id, &s_path.st, curdir->d_did,
+                                                  (char *)convname, strlen(convname));
                     AFP_CNID_DONE();
-                    if (cnid_up_ret != 0)
-                        LOG(log_error, logtype_afpd, "enumerate: error updating CNID of \"%s\"", fullpathname(convname));
+
+                    if (cnid_up_ret != 0) {
+                        LOG(log_error, logtype_afpd, "enumerate: error updating CNID of \"%s\"",
+                            fullpathname(convname));
+                    }
                 }
             }
         }
@@ -381,29 +415,35 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
          * inaccurate, since that means /dev/null is a file, /dev/printer
          * is a file, etc.
          */
-        if ( S_ISDIR(s_path.st.st_mode)) {
-            if ( dbitmap == 0 ) {
+        if (S_ISDIR(s_path.st.st_mode)) {
+            if (dbitmap == 0) {
                 continue;
             }
+
             int len = strlen(s_path.u_name);
+
             if ((dir = dircache_search_by_name(vol, curdir, s_path.u_name, len)) == NULL) {
                 if ((dir = dir_add(vol, curdir, &s_path, len)) == NULL) {
-                    LOG(log_error, logtype_afpd, "enumerate(vid:%u, did:%u, name:'%s'): error adding dir: '%s'",
+                    LOG(log_error, logtype_afpd,
+                        "enumerate(vid:%u, did:%u, name:'%s'): error adding dir: '%s'",
                         ntohs(vid), ntohl(did), o_path->u_name, s_path.u_name);
                     return AFPERR_MISC;
                 }
             }
-            if ((ret = getdirparams(obj, vol, dbitmap, &s_path, dir, data + header , &esz)) != AFP_OK)
-                return( ret );
 
+            if ((ret = getdirparams(obj, vol, dbitmap, &s_path, dir, data + header,
+                                    &esz)) != AFP_OK) {
+                return ret;
+            }
         } else {
-            if ( fbitmap == 0 ) {
+            if (fbitmap == 0) {
                 continue;
             }
+
             /* files are added to the dircache in getfilparams() -> getmetadata() */
-            if (AFP_OK != ( ret = getfilparams(obj, vol, fbitmap, &s_path, curdir,
-                                               data + header, &esz, 1)) ) {
-                return( ret );
+            if (AFP_OK != (ret = getfilparams(obj, vol, fbitmap, &s_path, curdir,
+                                              data + header, &esz, 1))) {
+                return ret;
             }
         }
 
@@ -411,95 +451,99 @@ static int enumerate(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
          * Make sure entry is an even length, possibly with a null
          * byte on the end.
          */
-        if ( (esz + header) & 1 ) {
-            *(data + header + esz ) = '\0';
+        if ((esz + header) & 1) {
+            *(data + header + esz) = '\0';
             esz++;
         }
 
         /*
          * Check if we've exceeded the size limit.
          */
-        if ( maxsz < sz + esz + header) {
+        if (maxsz < sz + esz + header) {
             if (first) { /* maxsz can't hold a single reply */
                 return AFPERR_PARAM;
             }
+
             sd.sd_last = start;
             break;
         }
 
-        if (first)
+        if (first) {
             first = 0;
+        }
 
         sz += esz + header;
+
         if (ext) {
-            temp16 = htons( esz + header );
-            memcpy( data, &temp16, sizeof( temp16 ));
+            temp16 = htons(esz + header);
+            memcpy(data, &temp16, sizeof(temp16));
             data += sizeof(temp16);
-        }
-        else {
+        } else {
             *data++ = esz + header;
         }
 
-        *data++ = S_ISDIR(s_path.st.st_mode) ? FILDIRBIT_ISDIR : FILDIRBIT_ISFILE;
+        *data++ = S_ISDIR(s_path.st.st_mode) ? (char) FILDIRBIT_ISDIR :
+                  FILDIRBIT_ISFILE;
+
         if (ext) {
-             *data++ = 0;
+            *data++ = 0;
         }
+
         data += esz;
         actcnt++;
         /* FIXME if we rollover 16 bits and it's not FPEnumerateExt2 */
     }
 
-    if ( actcnt == 0 ) {
+    if (actcnt == 0) {
         sd.sd_did = 0;		/* invalidate sd struct to force re-read */
+
         /*
          * in case were converting adouble stuff:
          * after enumerating the whole dir we should have converted everything
          * thus the .AppleDouble dir shouls be empty thus we can no try to
          * delete it
          */
-        if (vol->v_adouble == AD_VERSION_EA && ! (vol->v_flags & AFPVOL_NOV2TOEACONV))
+        if (vol->v_adouble == AD_VERSION_EA && !(vol->v_flags & AFPVOL_NOV2TOEACONV)) {
             (void)rmdir(".AppleDouble");
+        }
 
-        return( AFPERR_NOOBJ );
+        return AFPERR_NOOBJ;
     }
-    sd.sd_sindex = sindex + actcnt;
 
+    sd.sd_sindex = sindex + actcnt;
     /*
      * All done, fill in misc junk in rbuf
      */
-    fbitmap = htons( fbitmap );
-    memcpy( rbuf, &fbitmap, sizeof( fbitmap ));
-    rbuf += sizeof( fbitmap );
-    dbitmap = htons( dbitmap );
-    memcpy( rbuf, &dbitmap, sizeof( dbitmap ));
-    rbuf += sizeof( dbitmap );
-    actcnt = htons( actcnt );
-    memcpy( rbuf, &actcnt, sizeof( actcnt ));
-    rbuf += sizeof( actcnt );
+    fbitmap = htons(fbitmap);
+    memcpy(rbuf, &fbitmap, sizeof(fbitmap));
+    rbuf += sizeof(fbitmap);
+    dbitmap = htons(dbitmap);
+    memcpy(rbuf, &dbitmap, sizeof(dbitmap));
+    rbuf += sizeof(dbitmap);
+    actcnt = htons(actcnt);
+    memcpy(rbuf, &actcnt, sizeof(actcnt));
+    rbuf += sizeof(actcnt);
     *rbuflen = sz;
-    return( AFP_OK );
+    return AFP_OK;
 }
 
 /* ----------------------------- */
 int afp_enumerate(AFPObj *obj, char *ibuf, size_t ibuflen,
-    char *rbuf,
-    size_t *rbuflen)
+                  char *rbuf, size_t *rbuflen)
 {
-    return enumerate(obj, ibuf,ibuflen ,rbuf,rbuflen , 0);
+    return enumerate(obj, ibuf, ibuflen, rbuf, rbuflen, 0);
 }
 
 /* ----------------------------- */
 int afp_enumerate_ext(AFPObj *obj, char *ibuf, size_t ibuflen,
-    char *rbuf,
-    size_t *rbuflen)
+                      char *rbuf, size_t *rbuflen)
 {
-    return enumerate(obj, ibuf,ibuflen ,rbuf,rbuflen , 1);
+    return enumerate(obj, ibuf, ibuflen, rbuf, rbuflen, 1);
 }
 
 /* ----------------------------- */
 int afp_enumerate_ext2(AFPObj *obj, char *ibuf, size_t ibuflen,
-    char *rbuf,
-    size_t *rbuflen)
+                       char *rbuf, size_t *rbuflen)
 {
-    return enumerate(obj, ibuf,ibuflen ,rbuf,rbuflen , 2);
+    return enumerate(obj, ibuf, ibuflen, rbuf, rbuflen, 2);
 }
