@@ -19,8 +19,8 @@
 
 #define MANGLE_CHAR '#'
 #define MAX_MANGLE_SUFFIX_LENGTH 999
-#define MAX_EXT_LENGTH 5 /* XXX This cannot be greater than 27 */
-#define MANGLE_LENGTH  9 /* #ffffffff This really can't be changed. */
+#define MAX_EXT_LENGTH 5 /*!< XXX This cannot be greater than 27 */
+#define MANGLE_LENGTH  9 /*!< \#ffffffff This really can't be changed. */
 #define MAX_LENGTH MACFILELEN
 
 extern char *mangle(const struct vol *, char *, size_t, char *, cnid_t, int);
