@@ -1,6 +1,4 @@
 /*
- * $Id: switch.c,v 1.12.8.3 2009/09/11 12:40:14 franklahm Exp $
- *
  * Copyright (c) 1990,1991 Regents of The University of Michigan.
  * All Rights Reserved.
  *
@@ -29,40 +27,41 @@
 
 #include <stdio.h>  /* to pick up NULL */
 #include <sys/stat.h> /* works around a bug */
-#include <atalk/logger.h>
 
 #include <atalk/afp.h>
+#include <atalk/globals.h>
+#include <atalk/logger.h>
 #include <atalk/uam.h>
 
-#include "globals.h"
+#ifdef HAVE_ACLS
+#include "acls.h"
+#endif
 
 /* grab the FP functions */
-#include "auth.h" 
+#include "auth.h"
 #include "desktop.h"
-#include "switch.h"
-#include "fork.h"
-#include "file.h"
 #include "directory.h"
+#include "file.h"
 #include "filedir.h"
-#include "status.h"
+#include "fork.h"
 #include "misc.h"
+#include "status.h"
+#include "switch.h"
 
-static int afp_null(obj, ibuf, ibuflen, rbuf, rbuflen )
-AFPObj  *obj _U_;
-char	*ibuf, *rbuf _U_;
-int	ibuflen _U_, *rbuflen;
+static int afp_null(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_,
+                    char *rbuf _U_,  size_t *rbuflen)
 {
-    LOG(log_info, logtype_afpd, "afp_null handle %d", *ibuf );
+    LOG(log_info, logtype_afpd, "afp_null handle %d", *ibuf);
     *rbuflen = 0;
-    return( AFPERR_NOOP );
+    return AFPERR_NOOP;
 }
 
-/*
+/*!
  * Routines marked "NULL" are not AFP functions.
  * Routines marked "afp_null" are AFP functions
  * which are not yet implemented. A fine line...
  */
-int	(*preauth_switch[])() = {
+static AFPCmd preauth_switch[] = {
     NULL, NULL, NULL, NULL,
     NULL, NULL, NULL, NULL,					/*   0 -   7 */
     NULL, NULL, NULL, NULL,
@@ -129,9 +128,9 @@ int	(*preauth_switch[])() = {
     NULL, NULL, NULL, NULL,					/* 248 - 255 */
 };
 
-int	(**afp_switch)() = preauth_switch;
+AFPCmd *afp_switch = preauth_switch;
 
-int	(*postauth_switch[])() = {
+AFPCmd postauth_switch[] = {
     NULL, afp_bytelock, afp_closevol, afp_closedir,
     afp_closefork, afp_copyfile, afp_createdir, afp_createfile,	/*   0 -   7 */
     afp_delete, afp_enumerate, afp_flush, afp_flushfork,
@@ -152,7 +151,7 @@ int	(*postauth_switch[])() = {
     NULL, NULL, NULL, NULL,
     NULL, NULL, NULL, NULL,					/*  64 -  71 */
     NULL, NULL, NULL, NULL,
-    NULL, NULL, NULL, NULL,	                /*  72 -  79 */
+    NULL, NULL, afp_syncdir, afp_syncfork,	/*  72 -  79 */
     NULL, NULL, NULL, NULL,
     NULL, NULL, NULL, NULL,					/*  80 -  87 */
     NULL, NULL, NULL, NULL,
@@ -203,21 +202,31 @@ int	(*postauth_switch[])() = {
 /* add a new function if it's specified. return the old function in
  * "old" if there's a pointer there. */
 int uam_afpserver_action(const int id, const int which,
-                         int (*new)(), int (**old)())
+                         AFPCmd new_table, AFPCmd *old)
 {
     switch (which) {
     case UAM_AFPSERVER_PREAUTH:
-        if (old)
+        if (old) {
             *old = preauth_switch[id];
-        if (new)
-            preauth_switch[id] = new;
+        }
+
+        if (new_table) {
+            preauth_switch[id] = new_table;
+        }
+
         break;
+
     case UAM_AFPSERVER_POSTAUTH:
-        if (old)
+        if (old) {
             *old = postauth_switch[id];
-        if (new)
-            postauth_switch[id] = new;
+        }
+
+        if (new_table) {
+            postauth_switch[id] = new_table;
+        }
+
         break;
+
     default:
         LOG(log_debug, logtype_afpd, "uam_afpserver_action: unknown switch %d[%d]",
             which, id);
