@@ -10,10 +10,10 @@
 
 struct interface {
     struct interface	*i_next;
-    char		i_name[ IFNAMSIZ ];
+    char		i_name[IFNAMSIZ];
     int			i_flags;
     int			i_time;
-    int                 i_group; /* for isolated appletalk domains */
+    int                 i_group; /*!< for isolated appletalk domains */
     struct sockaddr_at	i_addr;
     struct sockaddr_at	i_caddr;
     struct ziptab	*i_czt;
@@ -24,24 +24,24 @@ struct interface {
 
 #define IFACE_PHASE1	0x001
 #define IFACE_PHASE2	0x002
-#define IFACE_LOOPBACK	0x004		/* is the loopback interface */
-#define IFACE_SEED	0x008		/* act as seed */
-#define IFACE_ADDR	0x010		/* has an address set */
-#define IFACE_CONFIG	0x020		/* has been configured */
-#define IFACE_NOROUTER	0x040		/* no router on interface */
-#define IFACE_LOOP	0x080		/* has a loopback route */
-#define IFACE_RSEED     0x100           /* almost the same as seed. RSEED
+#define IFACE_LOOPBACK	0x004		/*!< is the loopback interface */
+#define IFACE_SEED	0x008		/*!< act as seed */
+#define IFACE_ADDR	0x010		/*!< has an address set */
+#define IFACE_CONFIG	0x020		/*!< has been configured */
+#define IFACE_NOROUTER	0x040		/*!< no router on interface */
+#define IFACE_LOOP	0x080		/*!< has a loopback route */
+#define IFACE_RSEED     0x100           /*!< almost the same as seed. RSEED
 					   says that we should try to
 					   do routing. */
-#define IFACE_DONTROUTE 0x200           /* don't route this interface */
-#define IFACE_ISROUTER  0x400           /* act as a router. */
-#define IFACE_ERROR 	0x2000		/* sendto returned an error */
+#define IFACE_DONTROUTE 0x200           /*!< don't route this interface */
+#define IFACE_ISROUTER  0x400           /*!< act as a router. */
+#define IFACE_ERROR 	0x2000		/*!< sendto returned an error */
 
 #define UNSTABLE	2
 #define STABLE		0
 #define STABLEANYWAY	-2
 
-#define IFBASE		2	/* base number of interfaces */
+#define IFBASE		2	/*!< base number of interfaces */
 
 #ifdef __linux__
 #define LOOPIFACE	"lo"
@@ -51,6 +51,6 @@ struct interface {
 
 extern struct interface	*interfaces;
 extern struct interface	*ciface;
-struct interface	*newiface (const char *);
+struct interface	*newiface(const char *);
 
 #endif /* ATALKD_INTERFACE_H */
