@@ -22,18 +22,17 @@
 #endif /* __svr4__ */
 
 #include <atalk/util.h>
-#include <netatalk/endian.h>
 #include "rtmp.h"
 #include "zip.h"
 #include "main.h"
 #include "multicast.h"
 
 
-static const unsigned char	ethermulti[ 6 ] = {
+static const unsigned char	ethermulti[6] = {
     0x09, 0x00, 0x07, 0xff, 0xff, 0xff,
 };
 
-static const unsigned char	ethermultitab[ 253 ][ 6 ] = {
+static const unsigned char	ethermultitab[253][6] = {
     { 0x09, 0x00, 0x07, 0x00, 0x00, 0x00, },
     { 0x09, 0x00, 0x07, 0x00, 0x00, 0x01, },
     { 0x09, 0x00, 0x07, 0x00, 0x00, 0x02, },
@@ -290,77 +289,71 @@ static const unsigned char	ethermultitab[ 253 ][ 6 ] = {
 };
 
 
-
-/* configure multicast for a given named interface */
+/*! configure multicast for a given named interface */
 int addmulti(const char *name, const unsigned char *data)
 {
-#ifdef NO_DATA_LINK_PASSTHROUGH
-    struct sockaddr_dl sa;
-#else /* NO_DATA_LINK_PASSTHROUGH */
     struct sockaddr sa;
-#endif /* NO_DATA_LINK_PASSTHROUGH */
-
     memset(&sa, 0, sizeof(sa));
-#ifdef NO_DATA_LINK_PASSTHROUGH
-    sa.sdl_family = AF_LINK;
-    memcpy(LLADDR(&sa), data ? data : ethermulti, sizeof(ethermulti));
-    sa.sdl_alen = sizeof(ethermulti);
-    sa.sdl_len = sizeof(sa);
-#else /* NO_DATA_LINK_PASSTHROUGH */
     memcpy(sa.sa_data, data ? data : ethermulti, sizeof(ethermulti));
-#endif /* NO_DATA_LINK_PASSTHROUGH */
-    if (ifconfig(name, SIOCADDMULTI, (struct sockaddr_at *)&sa))
-      return -1;
+
+    if (ifconfig(name, SIOCADDMULTI, (struct sockaddr_at *)&sa)) {
+        return -1;
+    }
 
     return 0;
 }
 
-static u_int16_t
-atalk_cksum( u_char *data, int len)
+static uint16_t
+atalk_cksum(unsigned char *data, int len)
 {
-    u_char	*end;
-    u_int32_t	cksum = 0;
+    unsigned char	*end;
+    uint32_t	cksum = 0;
 
-    for ( end = data + len; data < end; data++ ) {
-	cksum = ( cksum + *data ) << 1;
-	if ( cksum & 0x00010000 ) {
-	    cksum++;
-	}
-	cksum &= 0x0000ffff;
+    for (end = data + len; data < end; data++) {
+        cksum = (cksum + *data) << 1;
+
+        if (cksum & 0x00010000) {
+            cksum++;
+        }
+
+        cksum &= 0x0000ffff;
     }
 
-    if ( cksum == 0 ) {
-	cksum = 0x0000ffff;
+    if (cksum == 0) {
+        cksum = 0x0000ffff;
     }
 
-    return( (u_int16_t) cksum );
+    return (uint16_t) cksum;
 }
 
-/*
- * Fill in multicast for zone.  There is a general issue here:  how can
- * we tell the type of interface we're configuring for?  E.g.  Is it
- * ethernet, tokenring, or FDDI?  (Of course, FDDI and Ethernet look just
- * alike.)
+/*!
+ * @brief Fill in multicast for zone.
+ *
+ * @note There is a general issue here:
+ * how can we tell the type of interface we're configuring for?
+ * E.g. Is it ethernet, tokenring, or FDDI?
+ * (Of course, FDDI and Ethernet look just alike.)
  */
 int
-zone_bcast( struct ziptab *zt)
+zone_bcast(struct ziptab *zt)
 {
-    u_char		uname[ 32 ];
-    u_int16_t		cksum;
+    unsigned char		uname[32];
+    uint16_t		cksum;
     int			i;
 
     if (!zt->zt_bcast &&
-	(zt->zt_bcast = (u_char *) malloc(sizeof( ethermulti ))) == NULL) {
-       LOG(log_error, logtype_atalkd, "zone_bcast malloc: %s", strerror(errno) );
-       return -1;
-     }
-
-    for ( i = 0; i < zt->zt_len; i++ ) {
-	uname[ i ] = diatoupper((int) zt->zt_name[ i ]);
+            (zt->zt_bcast = (unsigned char *) malloc(sizeof(ethermulti))) == NULL) {
+        LOG(log_error, logtype_atalkd, "zone_bcast malloc: %s", strerror(errno));
+        return -1;
     }
-    cksum = atalk_cksum( uname, zt->zt_len );
+
+    for (i = 0; i < zt->zt_len; i++) {
+        uname[i] = diatoupper((int) zt->zt_name[i]);
+    }
+
+    cksum = atalk_cksum(uname, zt->zt_len);
 #define elements(a)   (sizeof(a)/sizeof((a)[0]))
-    memcpy(zt->zt_bcast, ethermultitab[ cksum % elements( ethermultitab ) ],
-	   sizeof( ethermulti ));
+    memcpy(zt->zt_bcast, ethermultitab[cksum % elements(ethermultitab)],
+           sizeof(ethermulti));
     return 0;
 }
