@@ -10,18 +10,19 @@
 
 struct ziptab {
     struct ziptab	*zt_next,
-			*zt_prev;
-    u_char		zt_len;
+                 *zt_prev;
+    unsigned char		zt_len;
     char		*zt_name;
-    u_char		*zt_bcast;
+    unsigned char		*zt_bcast;
     struct list		*zt_rt;
 };
 
 extern struct ziptab	*ziptab, *ziplast;
-struct ziptab	*newzt (const int, const char *);
+struct ziptab	*newzt(const int, const char *);
 
-int addzone ( struct rtmptab *, int, char * );
-int zip_getnetinfo ( struct interface * );
-int zip_packet(struct atport *ap,struct sockaddr_at *from, char *data, int len);
+int addzone(struct rtmptab *, int, char *);
+int zip_getnetinfo(struct interface *);
+int zip_packet(struct atport *ap, struct sockaddr_at *from, char *data,
+               int len);
 
 #endif /* atalkd/zip.h */
