@@ -65,52 +65,10 @@ static struct cnid_dbd_rply rply _U_;
 static jmp_buf jmp;
 static char pname[MAXPATHLEN] = "../";
 
-/*
-  Taken form afpd/desktop.c
-*/
-static char *utompath(char *upath)
-{
-    /* for convert_charset dest_len parameter +2 */
-    static char  mpath[MAXPATHLEN + 2];
-    char         *m, *u;
-    uint16_t     flags = CONV_IGNORE | CONV_UNESCAPEHEX;
-    size_t       outlen;
-
-    if (!upath) {
-        return NULL;
-    }
-
-    m = mpath;
-    u = upath;
-    outlen = strlen(upath);
-
-    if (vol->v_casefold & AFPVOL_UTOMUPPER) {
-        flags |= CONV_TOUPPER;
-    } else if (vol->v_casefold & AFPVOL_UTOMLOWER) {
-        flags |= CONV_TOLOWER;
-    }
-
-    if (vol->v_flags & AFPVOL_EILSEQ) {
-        flags |= CONV__EILSEQ;
-    }
-
-    /* convert charsets */
-    if ((size_t) -1 == (outlen = convert_charset(vol->v_volcharset,
-                                 CH_UTF8_MAC,
-                                 vol->v_maccharset,
-                                 u, outlen, mpath, MAXPATHLEN, &flags))) {
-        dbd_log(LOGSTD, "Conversion from %s to %s for %s failed.",
-                vol->v_volcodepage, vol->v_maccodepage, u);
-        return NULL;
-    }
-
-    return m;
-}
-
-/*
-  Check for netatalk special folders e.g. ".AppleDB" or ".AppleDesktop"
-  Returns pointer to name or NULL.
-*/
+/*!
+ * @brief Check for netatalk special folders e.g. ".AppleDB" or ".AppleDesktop"
+ * @returns pointer to name or NULL.
+ */
 static const char *check_netatalk_dirs(const char *name)
 {
     const int max_dirs = 2;
@@ -124,10 +82,10 @@ static const char *check_netatalk_dirs(const char *name)
     return NULL;
 }
 
-/*
-  Check for special names
-  Returns pointer to name or NULL.
-*/
+/*!
+ * @brief Check for special names
+ * @returns pointer to name or NULL.
+ */
 static const char *check_special_dirs(const char *name)
 {
     const int max_dirs = 1;
@@ -141,7 +99,7 @@ static const char *check_special_dirs(const char *name)
     return NULL;
 }
 
-/*
+/*!
  * We unCAPed a name, update CNID db
  */
 static int update_cnid(cnid_t did, const struct stat *sp, const char *oldname,
@@ -166,9 +124,9 @@ static int update_cnid(cnid_t did, const struct stat *sp, const char *oldname,
     return 0;
 }
 
-/*
-  Check for .AppleDouble file, create if missing
-*/
+/*!
+ * Check for .AppleDouble file, create if missing
+ */
 static int check_adfile(const char *fname, const struct stat *st,
                         const char **newname)
 {
@@ -233,7 +191,7 @@ static int check_adfile(const char *fname, const struct stat *st,
         }
 
         /* Set name in ad-file */
-        ad_setname(&ad, utompath((char *)fname));
+        ad_setname(&ad, convert_utf8_to_mac(vol, fname));
         ad_flush(&ad);
         ad_close(&ad, ADFLAGS_HF);
         fd = open(adname, O_RDWR | O_NOFOLLOW);
@@ -260,9 +218,9 @@ static int check_adfile(const char *fname, const struct stat *st,
     return 0;
 }
 
-/*
-   Remove all files with file::EA* from adouble dir
-*/
+/*!
+ * Remove all files with file::EA* from adouble dir
+ */
 static void remove_eafiles(const char *name, struct ea *ea _U_)
 {
     DIR *dp = NULL;
@@ -313,9 +271,9 @@ exit:
     }
 }
 
-/*
-  Check Extended Attributes files
-*/
+/*!
+ * Check Extended Attributes files
+ */
 static int check_eafiles(const char *fname)
 {
     unsigned int  count = 0;
@@ -375,9 +333,9 @@ static int check_eafiles(const char *fname)
     return ret;
 }
 
-/*
-  Check for .AppleDouble folder and .Parent, create if missing
-*/
+/*!
+ * Check for .AppleDouble folder and .Parent, create if missing
+ */
 static int check_addir(int volroot _U_)
 {
     int addir_fd = -1;
@@ -461,7 +419,7 @@ static int check_addir(int volroot _U_)
         }
 
         /* Get basename of cwd from cwdbuf */
-        mname = utompath(strrchr(cwdbuf, '/') + 1);
+        mname = convert_utf8_to_mac(vol, strrchr(cwdbuf, '/') + 1);
         /* Update name in ad file */
         ad_setname(&ad, mname);
         ad_flush(&ad);
@@ -519,12 +477,11 @@ static int check_addir(int volroot _U_)
     return 0;
 }
 
-/*
-  Check if file cotains "::EA" and if it does check if its correspondig data fork exists.
-  Returns:
-  0 = name is not an EA file
-  1 = name is an EA file and no problem was found
-  -1 = name is an EA file and data fork is gone
+/*!
+ * @brief Check if file cotains "::EA" and if it does check if its correspondig data fork exists.
+ * @returns 0 = name is not an EA file
+ * @returns 1 = name is an EA file and no problem was found
+ * @returns -1 = name is an EA file and data fork is gone
  */
 static int check_eafile_in_adouble(const char *name)
 {
@@ -584,11 +541,11 @@ ea_check_done:
     return ret;
 }
 
-/*
-  Check files and dirs inside .AppleDouble folder:
-  - remove orphaned files
-  - bail on dirs
-*/
+/*!
+ * @brief Check files and dirs inside .AppleDouble folder
+ * @note remove orphaned files
+ * @note bail on dirs
+ */
 static int read_addir(void)
 {
     DIR *dp;
@@ -680,12 +637,10 @@ static int read_addir(void)
     return 0;
 }
 
-/*
-  Check CNID for a file/dir, both from db and from ad-file.
-  For detailed specs see intro.
-
-  @return Correct CNID of object or CNID_INVALID (ie 0) on error
-*/
+/*!
+ * @brief Check CNID for a file/dir, both from db and from ad-file.
+ * @returns Correct CNID of object or CNID_INVALID (ie 0) on error
+ */
 static cnid_t check_cnid(const char *name, cnid_t did, struct stat *st,
                          int adfile_ok)
 {
@@ -778,11 +733,11 @@ static int check_orphaned(const char *name)
     return 0;
 }
 
-/*
+/*!
   This is called recursively for all dirs.
   volroot=1 means we're in the volume root dir, 0 means we aren't.
   We use this when checking for netatalk private folders like .AppleDB.
-  did is our parents CNID.
+  did is our parent's CNID.
 */
 static int dbd_readdir(int volroot, cnid_t did)
 {
@@ -993,9 +948,9 @@ static int dbd_readdir(int volroot, cnid_t did)
     return ret;
 }
 
-/*
-  Main func called from cmd_dbd.c
-*/
+/*!
+ * Main func called from cmd_dbd.c
+ */
 int cmd_dbd_scanvol(struct vol *vol_in, dbd_flags_t flags)
 {
     EC_INIT;
