@@ -1,5 +1,6 @@
 
 /*
+ *
  * Copyright (C) Joerg Lenneis 2003
  * All Rights Reserved.  See COPYING.
  */
@@ -8,29 +9,27 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <string.h>
-#include <atalk/logger.h>
+#include <arpa/inet.h>
 #include <errno.h>
-#include <netatalk/endian.h>
-#include <atalk/cnid_dbd_private.h>
+#include <string.h>
+
+#include <atalk/cnid_bdb_private.h>
+#include <atalk/logger.h>
 
-#include "dbif.h"
 #include "dbd.h"
+#include "dbif.h"
 #include "pack.h"
 
-/* Return the unique stamp associated with this database */
+/*! Return the unique stamp associated with this database */
 
-int dbd_getstamp(DBD *dbd, struct cnid_dbd_rqst *rqst _U_, struct cnid_dbd_rply *rply)
+int dbd_getstamp(DBD *dbd, struct cnid_dbd_rqst *rqst _U_,
+                 struct cnid_dbd_rply *rply)
 {
     DBT key, data;
     int rc;
-
-
     memset(&key, 0, sizeof(key));
     memset(&data, 0, sizeof(data));
-
     rply->namelen = 0;
-
     key.data = ROOTINFO_KEY;
     key.size = ROOTINFO_KEYLEN;
 
@@ -39,13 +38,13 @@ int dbd_getstamp(DBD *dbd, struct cnid_dbd_rqst *rqst _U_, struct cnid_dbd_rply
         rply->result = CNID_DBD_RES_ERR_DB;
         return -1;
     }
-     
+
     if (rc == 0) {
-	LOG(log_error, logtype_cnid, "dbd_getstamp: No rootinfo record found");
+        LOG(log_error, logtype_cnid, "dbd_getstamp: No rootinfo record found");
         rply->result = CNID_DBD_RES_NOTFOUND;
         return 1;
     }
-    
+
     rply->namelen = CNID_DEV_LEN;
     rply->name = (char *)data.data + CNID_DEV_OFS;
     rply->result = CNID_DBD_RES_OK;
