@@ -1,10 +1,10 @@
 /*!
  * @file
- * Netatalk utility functions
+ * @brief Netatalk utility functions
  *
- * Utility functions for these areas: \n
- * * sockets \n
- * * locking \n
+ * Utility functions for these areas:
+ * * sockets
+ * * locking
  * * misc UNIX function wrappers, e.g. for getcwd
  */
 
@@ -18,33 +18,44 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <atalk/bstrlib.h>
+#include <bstrlib.h>
+
+#include <netatalk/at.h>
+
 #include <atalk/cnid.h>
 #include <atalk/unicode.h>
 
-/* exit error codes */
-#define EXITERR_CLNT 1  /* client related error */
-#define EXITERR_CONF 2  /* error in config files/cmd line parameters */
-#define EXITERR_SYS  3  /* local system error */
-#define EXITERR_CLOSED 4  /* connection was immediately closed after TCP handshake */
+#ifndef RLIM_MAX
+#ifdef __APPLE__
+#define RLIM_MAX 10240
+#else
+#define RLIM_MAX 65535
+#endif
+#endif
 
-/* Print a SBT and exit */
+/* exit error codes */
+#define EXITERR_CLNT 1  /*!< client related error */
+#define EXITERR_CONF 2  /*!< error in config files/cmd line parameters */
+#define EXITERR_SYS  3  /*!< local system error */
+#define EXITERR_CLOSED 4  /*!< connection was immediately closed after TCP handshake */
+
+/*! Print a SBT and exit */
 #define AFP_PANIC(why) \
     do {                                            \
         netatalk_panic(why);                        \
         abort();                                    \
     } while(0);
 
-/* LOG assert errors */
 #ifndef NDEBUG
+/*! LOG assert errors */
 #define AFP_ASSERT(b) \
     do {                                                                \
         if (!(b)) {                                                     \
             AFP_PANIC(#b);                                              \
         } \
-    } while(0);
+    } while(0)
 #else
-#define AFP_ASSERT(b)
+#define AFP_ASSERT(b) do {} while(0)
 #endif /* NDEBUG */
 
 #ifndef MIN
@@ -58,12 +69,6 @@
 #define STRCMP(a,b,c) (strcmp(a,c) b 0)
 #define ZERO_STRUCT(a) memset(&(a), 0, sizeof(a))
 #define ZERO_STRUCTP(a) memset((a), 0, sizeof(a))
-#ifndef MAX
-#define MAX(a,b) ((a) > (b) ? a : b)
-#endif
-#ifndef MIN
-#define MIN(a,b) ((a) < (b) ? a : b)
-#endif
 
 #ifdef WORDS_BIGENDIAN
 #define hton64(x)       (x)
@@ -79,7 +84,8 @@
 #endif
 
 #ifdef WITH_SENDFILE
-extern ssize_t sys_sendfile (int __out_fd, int __in_fd, off_t *__offset,size_t __count);
+extern ssize_t sys_sendfile(int __out_fd, int __in_fd, off_t *__offset,
+                            size_t __count);
 #endif
 
 extern const int _diacasemap[], _dialowermap[];
@@ -89,20 +95,23 @@ extern void freeifacelist(char **);
 
 #define diatolower(x)     _dialowermap[(unsigned char) (x)]
 #define diatoupper(x)     _diacasemap[(unsigned char) (x)]
-extern void bprint        (char *, int);
-extern int strdiacasecmp  (const char *, const char *);
-extern int strndiacasecmp (const char *, const char *, size_t);
-extern pid_t server_lock  (char * /*program*/, char * /*file*/, int /*debug*/);
-extern int check_lockfile (const char *program, const char *pidfile);
+#ifndef NO_DDP
+extern int atalk_aton(char *, struct at_addr *);
+#endif
+extern void bprint(char *, int);
+extern int strdiacasecmp(const char *, const char *);
+extern int strndiacasecmp(const char *, const char *, size_t);
+extern pid_t server_lock(char * /*program*/, char * /*file*/, int /*debug*/);
+extern int check_lockfile(const char *program, const char *pidfile);
 extern int create_lockfile(const char *program, const char *pidfile);
-extern void fault_setup	  (void (*fn)(void *));
+extern void fault_setup(void (*fn)(void *));
 extern void netatalk_panic(const char *why);
 #define server_unlock(x)  (unlink(x))
 
 #ifndef HAVE_DLFCN_H
-extern void *mod_open    (const char *);
-extern void *mod_symbol  (void *, const char *);
-extern void mod_close    (void *);
+extern void *mod_open(const char *);
+extern void *mod_symbol(void *, const char *);
+extern void mod_close(void *);
 #define mod_error()      ""
 #else /* ! HAVE_DLFCN_H */
 #include <dlfcn.h>
@@ -122,11 +131,7 @@ extern void mod_close    (void *);
 #define mod_open(a)      dlopen(a, RTLD_NOW)
 #endif /* __NetBSD__ */
 
-#ifndef DLSYM_PREPEND_UNDERSCORE
 #define mod_symbol(a, b) dlsym(a, b)
-#else /* ! DLSYM_PREPEND_UNDERSCORE */
-extern void *mod_symbol  (void *, const char *);
-#endif /* ! DLSYM_PREPEND_UNDERSCORE */
 #define mod_error()      dlerror()
 #define mod_close(a)     dlclose(a)
 #endif /* ! HAVE_DLFCN_H */
@@ -135,11 +140,21 @@ extern void *mod_symbol  (void *, const char *);
 #define strequal(a,b) (strcmp((a),(b)) == 0)
 #endif
 
+#define cfrombstr(b) ((char *)((b)->data))
+
+/*! strip slashes from end of a bstring */
+#define BSTRING_STRIP_SLASH(a)                      \
+    do {                                            \
+        while (bchar((a), blength(a) - 1) == '/')   \
+            bdelete((a), blength(a) - 1, 1);        \
+    } while (0);
+
 /******************************************************************
  * locking.c
  ******************************************************************/
 
-extern int lock_reg(int fd, int cmd, int type, off_t offest, int whence, off_t len);
+extern int lock_reg(int fd, int cmd, int type, off_t offest, int whence,
+                    off_t len);
 #define read_lock(fd, offset, whence, len) \
     lock_reg((fd), F_SETLK, F_RDLCK, (offset), (whence), (len))
 #define write_lock(fd, offset, whence, len) \
@@ -152,8 +167,10 @@ extern int lock_reg(int fd, int cmd, int type, off_t offest, int whence, off_t l
  ******************************************************************/
 
 extern int setnonblock(int fd, int cmd);
-extern ssize_t readt(int socket, void *data, const size_t length, int setnonblocking, int timeout);
-extern ssize_t writet(int socket, void *data, const size_t length, int setnonblocking, int timeout);
+extern ssize_t readt(int socket, void *data, const size_t length,
+                     int setnonblocking, int timeout);
+extern ssize_t writet(int socket, void *data, const size_t length,
+                      int setnonblocking, int timeout);
 extern const char *getip_string(const struct sockaddr *sa);
 extern unsigned int getip_port(const struct sockaddr *sa);
 extern void apply_ip_mask(struct sockaddr *ai, int maskbits);
@@ -164,27 +181,29 @@ extern int tokenize_ip_port(const char *ipurl, char **address, char **port);
 
 enum asev_fdtype {IPC_FD, LISTEN_FD};
 
-/**
- * atalk socket event data
- **/
+/*!
+ * @brief atalk socket event data
+ */
 struct asev_data {
-    enum asev_fdtype fdtype;  /* IPC fd or listening socket fd                 */
-    void            *private; /* pointer to AFPconfig for listening socket and *
-                               * pointer to afp_child_t for IPC fd             */
+    enum asev_fdtype fdtype;  /*!< IPC fd or listening socket fd */
+    void            *private; /*!< pointer to AFPconfig for listening socket and
+                               * pointer to afp_child_t for IPC fd */
+    int             protocol; /*!< protocol type ASP or DSI */
 };
 
-/**
- * atalk socket event
- **/
+/*!
+ * @brief atalk socket event
+ */
 struct asev {
-    struct pollfd         *fdset; /* struct pollfd array for poll() */
-    struct asev_data      *data;  /* associated array of data       */
+    struct pollfd         *fdset; /*!< struct pollfd array for poll() */
+    struct asev_data      *data;  /*!< associated array of data */
     int                    max;
     int                    used;
 };
 
 extern struct asev *asev_init(int max);
-extern bool asev_add_fd(struct asev *sev, int fd, enum asev_fdtype fdtype, void *private);
+extern bool asev_add_fd(struct asev *sev, int fd, enum asev_fdtype fdtype,
+                        void *private, int protocol);
 extern bool asev_del_fd(struct asev *sev, int fd);
 
 extern int send_fd(int socket, int fd);
@@ -198,11 +217,12 @@ extern const char *getcwdpath(void);
 extern const char *fullpathname(const char *);
 extern char *stripped_slashes_basename(char *p);
 extern void randombytes(void *buf, int n);
-extern int daemonize(int nochdir, int noclose);
+extern int daemonize(void);
 extern int run_cmd(const char *cmd, char **cmd_argv);
 extern char *realpath_safe(const char *path);
 extern const char *basename_safe(const char *path);
-extern char *strtok_quote (char *s, const char *delim);
+extern char *strtok_quote(char *s, const char *delim);
+extern const char *tmpdir(void);
 
 extern int ochdir(const char *dir, int options);
 extern int ostat(const char *path, struct stat *buf, int options);
@@ -215,13 +235,21 @@ extern int ochmod(char *path, mode_t mode, const struct stat *st, int options);
  *****************************************************************/
 
 extern bstring rel_path_in_vol(const char *path, const char *volpath);
-extern cnid_t cnid_for_path(struct _cnid_db *cdb, const char *volpath, const char *path, cnid_t *did);
+extern cnid_t cnid_for_path(struct _cnid_db *cdb, const char *volpath,
+                            const char *path, cnid_t *did);
+extern char *uuid_strip_dashes(const char *uuid);
 
 /******************************************************************
- * cnid.c
+ * gettok.c
  *****************************************************************/
 
-extern void initline   (int, char *);
-extern int  parseline  (int, char *);
+extern void initline(int, char *);
+extern int  parseline(int, char *);
+
+/******************************************************************
+ * pathconv.c
+ *****************************************************************/
+
+extern char *convert_utf8_to_mac(const struct vol *vol, const char *upath);
 
 #endif  /* _ATALK_UTIL_H */
