@@ -44,10 +44,12 @@ char *uuidtype[] = {"", "USER", "GROUP", "LOCAL"};
 static unsigned char local_group_uuid[] = {0xab, 0xcd, 0xef,
                                            0xab, 0xcd, 0xef,
                                            0xab, 0xcd, 0xef,
-                                           0xab, 0xcd, 0xef};
+                                           0xab, 0xcd, 0xef
+                                          };
 
 static unsigned char local_user_uuid[] = {0xff, 0xff, 0xee, 0xee, 0xdd, 0xdd,
-                                          0xcc, 0xcc, 0xbb, 0xbb, 0xaa, 0xaa};
+                                          0xcc, 0xcc, 0xbb, 0xbb, 0xaa, 0xaa
+                                         };
 
 void localuuid_from_id(unsigned char *buf, uuidtype_t type, unsigned int id)
 {
@@ -57,6 +59,7 @@ void localuuid_from_id(unsigned char *buf, uuidtype_t type, unsigned int id)
     case UUID_GROUP:
         memcpy(buf, local_group_uuid, 12);
         break;
+
     case UUID_USER:
     default:
         memcpy(buf, local_user_uuid, 12);
@@ -65,71 +68,77 @@ void localuuid_from_id(unsigned char *buf, uuidtype_t type, unsigned int id)
 
     tmp = htonl(id);
     memcpy(buf + 12, &tmp, 4);
-
     return;
 }
 
-/*
- * convert ascii string that can include dashes to binary uuid.
- * caller must provide a buffer.
+/*!
+ * @brief convert ascii string that can include dashes to binary uuid.
+ * @note caller must provide a buffer.
  */
-void uuid_string2bin( const char *uuidstring, unsigned char *uuid) {
+void uuid_string2bin(const char *uuidstring, unsigned char *uuid)
+{
     int nibble = 1;
     int i = 0;
     unsigned char c, val = 0;
 
     while (*uuidstring && i < UUID_BINSIZE) {
         c = *uuidstring;
+
         if (c == '-') {
             uuidstring++;
             continue;
-        }
-        else if (c <= '9')      /* 0-9 */
+        } else if (c <= '9') {  /* 0-9 */
             c -= '0';
-        else if (c <= 'F')  /* A-F */
+        } else if (c <= 'F') { /* A-F */
             c -= 'A' - 10;
-        else if (c <= 'f')      /* a-f */
-            c-= 'a' - 10;
+        } else if (c <= 'f') {  /* a-f */
+            c -= 'a' - 10;
+        }
 
-        if (nibble)
+        if (nibble) {
             val = c * 16;
-        else
+        } else {
             uuid[i++] = val + c;
+        }
 
         nibble ^= 1;
         uuidstring++;
     }
-
 }
 
 /*!
- * Convert 16 byte binary uuid to neat ascii represantation including dashes.
+ * @brief Convert 16 byte binary uuid to neat ascii represantation including dashes
+ *
  * Use defined or default ascii mask for dash placement
- * Returns pointer to static buffer.
+ * @returns pointer to static buffer
  */
-const char *uuid_bin2string(const unsigned char *uuid) {
+const char *uuid_bin2string(const unsigned char *uuid)
+{
     static char uuidstring[64];
     const char *uuidmask;
     int i = 0;
     unsigned char c;
-
 #ifdef HAVE_LDAP
-    if (ldap_uuid_string)
+
+    if (ldap_uuid_string) {
         uuidmask = ldap_uuid_string;
-    else
+    } else
 #endif
         uuidmask = "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx";
 
     LOG(log_debug, logtype_afpd, "uuid_bin2string{uuid}: mask: %s", uuidmask);
-		
+
     while (i < strlen(uuidmask)) {
         c = *uuid;
         uuid++;
         sprintf(uuidstring + i, "%02X", c);
         i += 2;
-        if (uuidmask[i] == '-')
+
+        if (uuidmask[i] == '-') {
             uuidstring[i++] = '-';
+        }
     }
+
     uuidstring[i] = 0;
     return uuidstring;
 }
@@ -138,20 +147,41 @@ const char *uuid_bin2string(const unsigned char *uuid) {
  * Interface
  ********************************************************/
 
-/*
- *   name: give me his name
- *   type: and type (UUID_USER or UUID_GROUP)
- *   uuid: pointer to uuid_t storage that the caller must provide
- * returns 0 on success !=0 on errror
+/*!
+ * @param name give me his name
+ * @param type and type (UUID_USER or UUID_GROUP)
+ * @param uuid pointer to uuid_t storage that the caller must provide
+ * @returns 0 on success !=0 on errror
  */
-int getuuidfromname( const char *name, uuidtype_t type, unsigned char *uuid) {
+int getuuidfromname(const char *name, uuidtype_t type, unsigned char *uuid)
+{
     int ret = 0;
     uuidtype_t mytype = type;
-    char nulluuid[16] = {0,0,0,0, 0,0,0,0, 0,0,0,0, 0,0,0,0};
+    char nulluuid[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+    /* Local copy to prevent corruption */
+    char name_copy[256];
+    /* Save original pointer and value to detect if caller's buffer was corrupted */
+    char original_check[256];
+    const char *original_ptr = name;
 #ifdef HAVE_LDAP
     char *uuid_string = NULL;
 #endif
 
+    if (name == NULL) {
+        LOG(log_error, logtype_afpd, "getuuidfromname: name is NULL");
+        return -1;
+    }
+
+    /* Copy name to local buffer to avoid pointer corruptions and improve security.
+     * Protects against the non-reentrant nature of getpwuid()/getgrgid().
+     * name pointer corrupted in race-condition for some ACL test cases */
+    snprintf(name_copy, sizeof(name_copy), "%s", name);
+    /* Save for corruption check */
+    snprintf(original_check, sizeof(original_check), "%s", name);
+    /* Use local copy from now on */
+    name = name_copy;
+    LOG(log_debug, logtype_afpd,
+        "getuuidfromname: START - name='%s', type=%d", name, type);
     ret = search_cachebyname(name, &mytype, uuid);
 
     if (ret == 0) {
@@ -162,37 +192,53 @@ int getuuidfromname( const char *name, uuidtype_t type, unsigned char *uuid) {
             (mytype & UUID_ENOENT) == UUID_ENOENT ? "[negative]" : "",
             uuidtype[type & UUIDTYPESTR_MASK],
             uuid_bin2string(uuid));
-        if ((mytype & UUID_ENOENT) == UUID_ENOENT)
+
+        if ((mytype & UUID_ENOENT) == UUID_ENOENT) {
+            LOG(log_debug, logtype_afpd,
+                "getuuidfromname: returning -1 due to UUID_ENOENT for '%s'", name);
             return -1;
+        }
     } else  {
         /* if not found in cache */
 #ifdef HAVE_LDAP
-        if ((ret = ldap_getuuidfromname( name, type, &uuid_string)) == 0) {
-            uuid_string2bin( uuid_string, uuid);
-            LOG(log_debug, logtype_afpd, "getuuidfromname{LDAP}: name: %s, type: %s -> UUID: %s",
+        if ((ret = ldap_getuuidfromname(name, type, &uuid_string)) == 0) {
+            uuid_string2bin(uuid_string, uuid);
+            LOG(log_debug, logtype_afpd,
+                "getuuidfromname{LDAP}: name: %s, type: %s -> UUID: %s",
                 name, uuidtype[type & UUIDTYPESTR_MASK], uuid_bin2string(uuid));
         } else {
-            LOG(log_debug, logtype_afpd, "getuuidfromname(\"%s\",t:%u): no result from ldap search",
+            LOG(log_debug, logtype_afpd,
+                "getuuidfromname(\"%s\",t:%u): no result from ldap search",
                 name, type);
         }
+
 #endif
+
         if (ret != 0) {
             /* Build a local UUID */
             if (type == UUID_USER) {
                 struct passwd *pwd;
+                LOG(log_debug, logtype_afpd,
+                    "getuuidfromname: calling getpwnam('%s')", name);
+
                 if ((pwd = getpwnam(name)) == NULL) {
-                    LOG(log_error, logtype_afpd, "getuuidfromname(\"%s\",t:%u): unknown user",
+                    LOG(log_error, logtype_afpd,
+                        "getuuidfromname(\"%s\",t:%u): unknown user (getpwnam returned NULL)",
                         name, uuidtype[type & UUIDTYPESTR_MASK]);
                     mytype |= UUID_ENOENT;
                     memcpy(uuid, nulluuid, 16);
                 } else {
+                    LOG(log_debug, logtype_afpd,
+                        "getuuidfromname: getpwnam('%s') succeeded, uid=%d", name, pwd->pw_uid);
                     localuuid_from_id(uuid, UUID_USER, pwd->pw_uid);
                     ret = 0;
-                    LOG(log_debug, logtype_afpd, "getuuidfromname{local}: name: %s, type: %s -> UUID: %s",
+                    LOG(log_debug, logtype_afpd,
+                        "getuuidfromname{local}: name: %s, type: %s -> UUID: %s",
                         name, uuidtype[type & UUIDTYPESTR_MASK], uuid_bin2string(uuid));
                 }
             } else {
                 struct group *grp;
+
                 if ((grp = getgrnam(name)) == NULL) {
                     LOG(log_error, logtype_afpd, "getuuidfromname(\"%s\",t:%u): unknown user",
                         name, uuidtype[type & UUIDTYPESTR_MASK]);
@@ -201,30 +247,48 @@ int getuuidfromname( const char *name, uuidtype_t type, unsigned char *uuid) {
                 } else {
                     localuuid_from_id(uuid, UUID_GROUP, grp->gr_gid);
                     ret = 0;
-                    LOG(log_debug, logtype_afpd, "getuuidfromname{local}: name: %s, type: %s -> UUID: %s",
+                    LOG(log_debug, logtype_afpd,
+                        "getuuidfromname{local}: name: %s, type: %s -> UUID: %s",
                         name, uuidtype[type & UUIDTYPESTR_MASK], uuid_bin2string(uuid));
                 }
             }
         }
+
         add_cachebyname(name, uuid, mytype, 0);
     }
 
 #ifdef HAVE_LDAP
-    if (uuid_string) free(uuid_string);
+
+    if (uuid_string) {
+        free(uuid_string);
+    }
+
 #endif
+
+    /* Check if the original name pointer was corrupted during execution */
+    if (original_ptr != NULL && strcmp(original_ptr, original_check) != 0) {
+        LOG(log_error, logtype_afpd,
+            "uuid.c:getuuidfromname: CORRUPTION DETECTED - caller's name buffer overwritten!"
+            "Original='%s', Now='%s'. Error handled, but caller should be fixed.",
+            original_check, original_ptr);
+    }
+
+    LOG(log_debug, logtype_afpd,
+        "getuuidfromname: END - name='%s', ret=%d", name, ret);
     return ret;
 }
 
 
-/*
- * uuidp: pointer to a uuid
- * name: returns allocated buffer from ldap_getnamefromuuid
- * type: returns USER, GROUP or LOCAL
- * return 0 on success !=0 on errror
+/*!
+ * @param uuidp pointer to a uuid
+ * @param name returns allocated buffer from ldap_getnamefromuuid
+ * @param type returns USER, GROUP or LOCAL
+ * @returns 0 on success !=0 on errror
  *
- * Caller must free name appropriately.
+ * @note Caller must free name appropriately.
  */
-int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type) {
+int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type)
+{
     int ret;
     uid_t uid;
     gid_t gid;
@@ -240,8 +304,11 @@ int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type) {
             *name,
             (*type & UUID_ENOENT) == UUID_ENOENT ? "[negative]" : "",
             uuidtype[(*type) & UUIDTYPESTR_MASK]);
-        if ((*type & UUID_ENOENT) == UUID_ENOENT)
+
+        if ((*type & UUID_ENOENT) == UUID_ENOENT) {
             return -1;
+        }
+
         return 0;
     }
 
@@ -252,6 +319,7 @@ int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type) {
         *type = UUID_USER;
         memcpy(&tmp, uuidp + 12, sizeof(uint32_t));
         uid = ntohl(tmp);
+
         if ((pwd = getpwuid(uid)) == NULL) {
             /* not found, add negative entry to cache */
             *name = NULL;
@@ -262,14 +330,17 @@ int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type) {
             add_cachebyuuid(uuidp, *name, *type, 0);
             ret = 0;
         }
+
         LOG(log_debug, logtype_afpd,
             "getnamefromuuid{local}: UUID: %s -> name: %s, type:%s",
-            uuid_bin2string(uuidp), *name ? *name : "-", uuidtype[(*type) & UUIDTYPESTR_MASK]);
+            uuid_bin2string(uuidp), *name ? *name : "-",
+            uuidtype[(*type) & UUIDTYPESTR_MASK]);
         return ret;
     } else if (memcmp(uuidp, local_group_uuid, 12) == 0) {
         *type = UUID_GROUP;
         memcpy(&tmp, uuidp + 12, sizeof(uint32_t));
         gid = ntohl(tmp);
+
         if ((grp = getgrgid(gid)) == NULL) {
             /* not found, add negative entry to cache */
             add_cachebyuuid(uuidp, "UUID_ENOENT", UUID_ENOENT, 0);
@@ -279,6 +350,7 @@ int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type) {
             add_cachebyuuid(uuidp, *name, *type, 0);
             ret = 0;
         }
+
         return ret;
     }
 
@@ -296,9 +368,8 @@ int getnamefromuuid(const uuidp_t uuidp, char **name, uuidtype_t *type) {
     }
 
     add_cachebyuuid(uuidp, *name, *type, 0);
-
-    LOG(log_debug, logtype_afpd, "getnamefromuuid{LDAP}: UUID: %s -> name: %s, type:%s",
+    LOG(log_debug, logtype_afpd,
+        "getnamefromuuid{LDAP}: UUID: %s -> name: %s, type:%s",
         uuid_bin2string(uuidp), *name, uuidtype[(*type) & UUIDTYPESTR_MASK]);
-
     return 0;
 }
