@@ -49,7 +49,7 @@ static const uint32_t set_eid[] = {
 
 #define EID_DISK(a) (set_eid[a])
 
-/*
+/*!
  * Prepare ad->ad_data buffer from struct adouble for writing on disk
  */
 int ad_rebuild_adouble_header_v2(struct adouble *ad)
@@ -398,7 +398,10 @@ EC_CLEANUP:
     EC_EXIT;
 }
 
-/* Flush resofork adouble file if any (currently adouble:ea and #ifndef HAVE_EAFD e.g. Linux) */
+/*!
+ * @brief Flush resofork adouble file if any
+ * @note currently adouble:ea and \#ifndef HAVE_EAFD e.g. Linux
+ */
 static int ad_flush_rf(struct adouble *ad)
 {
     ssize_t len;
@@ -548,16 +551,16 @@ int ad_close(struct adouble *ad, int adflags)
                 adf_lock_free(ad->ad_rfp);
             }
 
-        if (ad->ad_vers == AD_VERSION_EA) {
-            if ((ad_reso_fileno(ad) != -1)
-                    && !(--ad->ad_rfp->adf_refcount)) {
-                if (close(ad->ad_rfp->adf_fd) < 0) {
-                    err = -1;
-                }
-
-                ad->ad_rlen = 0;
-                ad_reso_fileno(ad) = -1;
+        /* Check version is EA and fd is not AD_SYMLINK (-2) or -1 */
+        if ((ad->ad_vers == AD_VERSION_EA)
+                && (ad_reso_fileno(ad) >= 0)
+                && !(--ad->ad_rfp->adf_refcount)) {
+            if (close(ad->ad_rfp->adf_fd) < 0) {
+                err = -1;
             }
+
+            ad->ad_rlen = 0;
+            ad_reso_fileno(ad) = -1;
         }
     }
 
