@@ -11,7 +11,6 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/uio.h>
-#include <netatalk/endian.h>
 #include <netatalk/at.h>
 #include <atalk/atp.h>
 #include <atalk/asp.h>
@@ -21,17 +20,14 @@ int asp_shutdown(ASP asp)
     struct atp_block	atpb;
     struct iovec	iov;
     char		*p;
-    u_int16_t		seq;
-    u_int8_t		oport;
-
-
+    uint16_t		seq;
+    uint8_t		oport;
     p = asp->commands;
     *p++ = ASPFUNC_CLOSE;
     *p++ = asp->asp_sid;
     seq = 0;
-    memcpy( p, &seq, sizeof(seq));
+    memcpy(p, &seq, sizeof(seq));
     p += sizeof(seq);
-
     oport = asp->asp_sat.sat_port;
     atpb.atp_saddr = &asp->asp_sat;
     atpb.atp_saddr->sat_port = asp->asp_wss;
@@ -40,9 +36,9 @@ int asp_shutdown(ASP asp)
     atpb.atp_sreqto = 2;
     atpb.atp_sreqtries = 5;
 
-    if ( atp_sreq( asp->asp_atp, &atpb, 1, ATP_XO ) < 0 ) {
-	asp->asp_sat.sat_port = oport;
-	return( -1 );
+    if (atp_sreq(asp->asp_atp, &atpb, 1, ATP_XO) < 0) {
+        asp->asp_sat.sat_port = oport;
+        return -1;
     }
 
     iov.iov_base = asp->commands;
@@ -50,11 +46,11 @@ int asp_shutdown(ASP asp)
     atpb.atp_rresiov = &iov;
     atpb.atp_rresiovcnt = 1;
 
-    if ( atp_rresp( asp->asp_atp, &atpb ) < 0 ) {
-	asp->asp_sat.sat_port = oport;
-	return( -1 );
+    if (atp_rresp(asp->asp_atp, &atpb) < 0) {
+        asp->asp_sat.sat_port = oport;
+        return -1;
     }
-    asp->asp_sat.sat_port = oport;
 
-    return( 0 );
+    asp->asp_sat.sat_port = oport;
+    return 0;
 }
