@@ -30,81 +30,86 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <errno.h>
+#include <unistd.h>
 
 #include <netinet/in.h>
 #include <netatalk/at.h>
-#include <netatalk/endian.h>
 #include <atalk/atp.h>
 
 #include "atp_internals.h"
 
+#ifdef EBUG
+#include <stdio.h>
+#endif /* EBUG */
 
-/* wait for a tranasaction service request
-*/
-int atp_rreq(
-    ATP			ah,		/* open atp handle */
-    struct atp_block	*atpb)		/* parameter block */
+
+/*!
+ * @brief wait for a transaction service request
+ * @param ah open atp handle
+ * @param atpb parameter block
+ */
+int atp_rreq(ATP ah, struct atp_block *atpb)
 {
     struct atpbuf	*req_buf;	/* for receiving request packet */
     struct atphdr	req_hdr;	/* request header overlay */
     struct sockaddr_at	faddr;		/* sender's address */
     int			recvlen;	/* length of received packet */
-    u_int16_t		tid;
+    uint16_t		tid;
     int			rc;
-    u_int8_t		func;
-
+    uint8_t		func;
 #ifdef EBUG
-    atp_print_bufuse( ah, "atp_rreq" );
+    atp_print_bufuse(ah, "atp_rreq");
 #endif /* EBUG */
 
-    while (( rc = atp_rsel( ah, atpb->atp_saddr, ATP_TREQ )) == 0 ) {
-	;
+    while ((rc = atp_rsel(ah, atpb->atp_saddr, ATP_TREQ)) == 0) {
+        ;
     }
 
-    if ( rc != ATP_TREQ ) {
+    if (rc != ATP_TREQ) {
 #ifdef EBUG
-	printf( "<%d> atp_rreq: atp_rsel returns err %d\n", getpid(), rc );
+        printf("<%d> atp_rreq: atp_rsel returns err %d\n", getpid(), rc);
 #endif /* EBUG */
-	return( rc );
+        return rc;
     }
 
     /* allocate a buffer for receiving request
     */
-    if (( req_buf = atp_alloc_buf()) == NULL ) {
-	return -1;
+    if ((req_buf = atp_alloc_buf()) == NULL) {
+        return -1;
     }
 
-    memcpy( &faddr, atpb->atp_saddr, sizeof( struct sockaddr_at ));
+    memcpy(&faddr, atpb->atp_saddr, sizeof(struct sockaddr_at));
     func = ATP_TREQ;
-    if (( recvlen = atp_recv_atp( ah, &faddr, &func, ATP_TIDANY,
-	  req_buf->atpbuf_info.atpbuf_data, 1 )) < 0 ) {
-	atp_free_buf( req_buf );
-	return -1;
+
+    if ((recvlen = atp_recv_atp(ah, &faddr, &func, ATP_TIDANY,
+                                req_buf->atpbuf_info.atpbuf_data, 1)) < 0) {
+        atp_free_buf(req_buf);
+        return -1;
     }
 
-    memcpy( &req_hdr, req_buf->atpbuf_info.atpbuf_data + 1, 
-	    sizeof( struct atphdr ));
-    tid = ntohs( req_hdr.atphd_tid );
-
+    memcpy(&req_hdr, req_buf->atpbuf_info.atpbuf_data + 1,
+           sizeof(struct atphdr));
+    tid = ntohs(req_hdr.atphd_tid);
     ah->atph_rtid = tid;
-    if (( ah->atph_rxo = req_hdr.atphd_ctrlinfo & ATP_XO ) != 0 ) {
-	ah->atph_rreltime = ATP_RELTIME *
-		( 1 << ( req_hdr.atphd_ctrlinfo & ATP_TRELMASK ));
+
+    if ((ah->atph_rxo = req_hdr.atphd_ctrlinfo & ATP_XO) != 0) {
+        ah->atph_rreltime = ATP_RELTIME *
+                            (1 << (req_hdr.atphd_ctrlinfo & ATP_TRELMASK));
     }
 
-    memcpy( atpb->atp_saddr, &faddr, sizeof( struct sockaddr_at ));
+    memcpy(atpb->atp_saddr, &faddr, sizeof(struct sockaddr_at));
 
-    if ( recvlen - ATP_HDRSIZE > atpb->atp_rreqdlen ) {
-	atp_free_buf( req_buf );
-	errno = EMSGSIZE;
-	return -1;
+    if (recvlen - ATP_HDRSIZE > atpb->atp_rreqdlen) {
+        atp_free_buf(req_buf);
+        errno = EMSGSIZE;
+        return -1;
     }
 
     atpb->atp_rreqdlen = recvlen - ATP_HDRSIZE;
-    memcpy( atpb->atp_rreqdata, 
-	    req_buf->atpbuf_info.atpbuf_data + ATP_HDRSIZE,
-	    recvlen - ATP_HDRSIZE );
+    memcpy(atpb->atp_rreqdata,
+           req_buf->atpbuf_info.atpbuf_data + ATP_HDRSIZE,
+           recvlen - ATP_HDRSIZE);
     atpb->atp_bitmap = req_hdr.atphd_bitmap;
-    atp_free_buf( req_buf );
-    return( 0 );
+    atp_free_buf(req_buf);
+    return 0;
 }
