@@ -7,6 +7,10 @@
  * by the Free Software Foundation version 2 of the License or later
  * version if explicitly stated by any of above copyright holders.
  *
+ * 2024/07/05: Rafal Lewczuk gave permission to change the license
+ * to a later verion of the GNU GPL in
+ * https://github.com/Netatalk/netatalk/issues/1193
+ *
  */
 #define USE_LIST
 
@@ -32,22 +36,23 @@
 #include <atalk/util.h>
 #include <atalk/volume.h>
 
-/* List of all registered modules. */
+/*! List of all registered modules. */
 static struct list_head modules = ATALK_LIST_HEAD_INIT(modules);
 
 static sigset_t sigblockset;
 
 /* Registers new CNID backend module. */
 
-/* Once module has been registered, it cannot be unregistered. */
+/*! Once module has been registered, it cannot be unregistered. */
 void cnid_register(struct _cnid_module *module)
 {
     struct list_head *ptr;
-
     /* Check if our module is already registered. */
     list_for_each(ptr, &modules)
-        if (0 == strcmp(list_entry(ptr, cnid_module, db_list)->name, module->name)) {
-        LOG(log_error, logtype_afpd, "Module with name [%s] is already registered !", module->name);
+
+    if (0 == strcmp(list_entry(ptr, cnid_module, db_list)->name, module->name)) {
+        LOG(log_error, logtype_afpd, "Module with name [%s] is already registered !",
+            module->name);
         return;
     }
 
@@ -59,38 +64,43 @@ void cnid_register(struct _cnid_module *module)
 /* --------------- */
 static int cnid_dir(const char *dir, mode_t mask)
 {
-   struct stat st, st1;
-   char tmp[MAXPATHLEN];
+    struct stat st, st1;
+    char tmp[MAXPATHLEN];
 
-   if (stat(dir, &st) < 0) {
-       if (errno != ENOENT)
-           return -1;
-       if (ad_stat( dir, &st) < 0)
-          return -1;
+    if (ad_stat(dir, &st) < 0) {
+        return -1;
+    }
 
-       LOG(log_info, logtype_cnid, "Setting uid/gid to %d/%d", st.st_uid, st.st_gid);
-       if (setegid(st.st_gid) < 0 || seteuid(st.st_uid) < 0) {
-           LOG(log_error, logtype_cnid, "uid/gid: %s", strerror(errno));
-           return -1;
-       }
+    LOG(log_info, logtype_cnid, "Setting uid/gid to %d/%d", st.st_uid, st.st_gid);
 
-       if (mkdir(dir, 0777 & ~mask) < 0)
-           return -1;
-   } else {
-       strlcpy(tmp, dir, sizeof(tmp));
-       strlcat(tmp, "/.AppleDB", sizeof(tmp));
-       if (stat(tmp, &st1) < 0) /* use .AppleDB owner, if folder already exists */
-           st1 = st;
-       LOG(log_info, logtype_cnid, "Setting uid/gid to %d/%d", st1.st_uid, st1.st_gid);
-       if (setegid(st1.st_gid) < 0 || seteuid(st1.st_uid) < 0) {
-           LOG(log_error, logtype_cnid, "uid/gid: %s", strerror(errno));
-           return -1;
-       }
-   }
-   return 0;
+    if (setegid(st.st_gid) < 0 || seteuid(st.st_uid) < 0) {
+        LOG(log_error, logtype_cnid, "uid/gid: %s", strerror(errno));
+        return -1;
+    }
+
+    if (mkdir(dir, 0777 & ~mask) < 0 && errno != EEXIST) {
+        return -1;
+    }
+
+    strlcpy(tmp, dir, sizeof(tmp));
+    strlcat(tmp, "/.AppleDB", sizeof(tmp));
+
+    /* use .AppleDB owner, if folder already exists */
+    if (stat(tmp, &st1) < 0) {
+        st1 = st;
+    }
+
+    LOG(log_info, logtype_cnid, "Setting uid/gid to %d/%d", st1.st_uid, st1.st_gid);
+
+    if (setegid(st1.st_gid) < 0 || seteuid(st1.st_uid) < 0) {
+        LOG(log_error, logtype_cnid, "uid/gid: %s", strerror(errno));
+        return -1;
+    }
+
+    return 0;
 }
 
-/* Opens CNID database using particular back-end */
+/*! Opens CNID database using particular back-end */
 struct _cnid_db *cnid_open(struct vol *vol, char *type, int flags)
 {
     struct _cnid_db *db;
@@ -98,31 +108,34 @@ struct _cnid_db *cnid_open(struct vol *vol, char *type, int flags)
     struct list_head *ptr;
     uid_t uid = -1;
     gid_t gid = -1;
-
     list_for_each(ptr, &modules) {
         if (0 == strcmp(list_entry(ptr, cnid_module, db_list)->name, type)) {
-	    mod = list_entry(ptr, cnid_module, db_list);
-        break;
+            mod = list_entry(ptr, cnid_module, db_list);
+            break;
         }
     }
 
     if (NULL == mod) {
-        LOG(log_error, logtype_afpd, "Cannot find module named [%s] in registered module list!", type);
+        LOG(log_error, logtype_afpd,
+            "Cannot find module named [%s] in registered module list!", type);
         return NULL;
     }
 
     if (mod->flags & CNID_FLAG_SETUID) {
         uid = geteuid();
         gid = getegid();
+
         if (seteuid(0)) {
             LOG(log_error, logtype_afpd, "seteuid failed %s", strerror(errno));
             return NULL;
         }
+
         if (cnid_dir(vol->v_path, vol->v_umask) < 0) {
-            if ( setegid(gid) < 0 || seteuid(uid) < 0) {
+            if (setegid(gid) < 0 || seteuid(uid) < 0) {
                 LOG(log_error, logtype_afpd, "can't seteuid back %s", strerror(errno));
                 exit(EXITERR_SYS);
             }
+
             return NULL;
         }
     }
@@ -135,21 +148,23 @@ struct _cnid_db *cnid_open(struct vol *vol, char *type, int flags)
     db = mod->cnid_open(&args);
 
     if (mod->flags & CNID_FLAG_SETUID) {
-      if ((geteuid() != 0) && (seteuid(0) < 0)) {
-				LOG(log_error, logtype_afpd,
-				    "can't seteuid to 0 (%s)", strerror(errno));
-				exit(EXITERR_SYS);
-  		}
-  		if ((gid != getegid()) && (setegid(gid) < 0)) {
-				LOG(log_error, logtype_afpd,
-				    "can't setegid to %i (%s)", gid, strerror(errno));
-				exit(EXITERR_SYS);
-  		}
-  		if ((uid != geteuid()) && (seteuid(uid) < 0)) {
-				LOG(log_error, logtype_afpd,
-				    "can't seteuid to %i (%s)", uid, strerror(errno));
-				exit(EXITERR_SYS);
-  		}
+        if ((geteuid() != 0) && (seteuid(0) < 0)) {
+            LOG(log_error, logtype_afpd,
+                "can't seteuid to 0 (%s)", strerror(errno));
+            exit(EXITERR_SYS);
+        }
+
+        if ((gid != getegid()) && (setegid(gid) < 0)) {
+            LOG(log_error, logtype_afpd,
+                "can't setegid to %i (%s)", gid, strerror(errno));
+            exit(EXITERR_SYS);
+        }
+
+        if ((uid != geteuid()) && (seteuid(uid) < 0)) {
+            LOG(log_error, logtype_afpd,
+                "can't seteuid to %i (%s)", uid, strerror(errno));
+            exit(EXITERR_SYS);
+        }
     }
 
     if (NULL == db) {
@@ -158,8 +173,10 @@ struct _cnid_db *cnid_open(struct vol *vol, char *type, int flags)
     }
 
     db->cnid_db_flags |= mod->flags;
-    if (flags & CNID_FLAG_NODEV)
+
+    if (flags & CNID_FLAG_NODEV) {
         db->cnid_db_flags |= CNID_FLAG_NODEV;
+    }
 
     if (db->cnid_db_flags & CNID_FLAG_BLOCK) {
         sigemptyset(&sigblockset);
@@ -176,7 +193,7 @@ struct _cnid_db *cnid_open(struct vol *vol, char *type, int flags)
 /* ------------------- */
 static void block_signal(uint32_t flags)
 {
-    if ((flags & CNID_FLAG_BLOCK)) {
+    if (flags & CNID_FLAG_BLOCK) {
         pthread_sigmask(SIG_BLOCK, &sigblockset, NULL);
     }
 }
@@ -184,32 +201,36 @@ static void block_signal(uint32_t flags)
 /* ------------------- */
 static void unblock_signal(uint32_t flags)
 {
-    if ((flags & CNID_FLAG_BLOCK)) {
+    if (flags & CNID_FLAG_BLOCK) {
         pthread_sigmask(SIG_UNBLOCK, &sigblockset, NULL);
     }
 }
 
-/* -------------------
+/*!
   protect against bogus value from the DB.
   adddir really doesn't like 2
 */
 static cnid_t valide(cnid_t id)
 {
-  if (id == CNID_INVALID)
-      return id;
-
-  if (id < CNID_START) {
-    static int err = 0;
-    if (!err) {
-        err = 1;
-        LOG(log_error, logtype_afpd, "Error: Invalid cnid, corrupted DB?");
+    if (id == CNID_INVALID) {
+        return id;
     }
-    return CNID_INVALID;
-  }
-  return id;
+
+    if (id < CNID_START) {
+        static int err = 0;
+
+        if (!err) {
+            err = 1;
+            LOG(log_error, logtype_afpd, "Error: Invalid cnid, corrupted DB?");
+        }
+
+        return CNID_INVALID;
+    }
+
+    return id;
 }
 
-/* Closes CNID database. Currently it's just a wrapper around db->cnid_close(). */
+/*! Closes CNID database. Currently it's just a wrapper around db->cnid_close(). */
 void cnid_close(struct _cnid_db *db)
 {
     uint32_t flags;
@@ -218,6 +239,7 @@ void cnid_close(struct _cnid_db *db)
         LOG(log_error, logtype_afpd, "Error: cnid_close called with NULL argument !");
         return;
     }
+
     /* cnid_close free db */
     flags = db->cnid_db_flags;
     block_signal(flags);
@@ -231,8 +253,9 @@ cnid_t cnid_add(struct _cnid_db *cdb, const struct stat *st, const cnid_t did,
 {
     cnid_t ret;
 
-    if (len == 0)
+    if (len == 0) {
         return CNID_INVALID;
+    }
 
     block_signal(cdb->cnid_db_flags);
     ret = valide(cdb->cnid_add(cdb, st, did, name, len, hint));
@@ -243,8 +266,7 @@ cnid_t cnid_add(struct _cnid_db *cdb, const struct stat *st, const cnid_t did,
 /* --------------- */
 int cnid_delete(struct _cnid_db *cdb, cnid_t id)
 {
-int ret;
-
+    int ret;
     block_signal(cdb->cnid_db_flags);
     ret = cdb->cnid_delete(cdb, id);
     unblock_signal(cdb->cnid_db_flags);
@@ -253,10 +275,10 @@ int ret;
 
 
 /* --------------- */
-cnid_t cnid_get(struct _cnid_db *cdb, const cnid_t did, char *name,const size_t len)
+cnid_t cnid_get(struct _cnid_db *cdb, const cnid_t did, char *name,
+                const size_t len)
 {
-cnid_t ret;
-
+    cnid_t ret;
     block_signal(cdb->cnid_db_flags);
     ret = valide(cdb->cnid_get(cdb, did, name, len));
     unblock_signal(cdb->cnid_db_flags);
@@ -266,18 +288,22 @@ cnid_t ret;
 /* --------------- */
 int cnid_getstamp(struct _cnid_db *cdb,  void *buffer, const size_t len)
 {
-cnid_t ret;
-time_t t;
+    cnid_t ret;
+    time_t t;
 
     if (!cdb->cnid_getstamp) {
         memset(buffer, 0, len);
-    	/* return the current time. it will invalide cache */
-    	if (len < sizeof(time_t))
-    	    return -1;
-    	t = time(NULL);
-    	memcpy(buffer, &t, sizeof(time_t));
+
+        /* return the current time. it will invalide cache */
+        if (len < sizeof(time_t)) {
+            return -1;
+        }
+
+        t = time(NULL);
+        memcpy(buffer, &t, sizeof(time_t));
         return 0;
     }
+
     block_signal(cdb->cnid_db_flags);
     ret = cdb->cnid_getstamp(cdb, buffer, len);
     unblock_signal(cdb->cnid_db_flags);
@@ -285,11 +311,11 @@ time_t t;
 }
 
 /* --------------- */
-cnid_t cnid_lookup(struct _cnid_db *cdb, const struct stat *st, const cnid_t did,
+cnid_t cnid_lookup(struct _cnid_db *cdb, const struct stat *st,
+                   const cnid_t did,
                    char *name, const size_t len)
 {
     cnid_t ret;
-
     block_signal(cdb->cnid_db_flags);
     ret = valide(cdb->cnid_lookup(cdb, st, did, name, len));
     unblock_signal(cdb->cnid_db_flags);
@@ -297,7 +323,8 @@ cnid_t cnid_lookup(struct _cnid_db *cdb, const struct stat *st, const cnid_t did
 }
 
 /* --------------- */
-int cnid_find(struct _cnid_db *cdb, const char *name, size_t namelen, void *buffer, size_t buflen)
+int cnid_find(struct _cnid_db *cdb, const char *name, size_t namelen,
+              void *buffer, size_t buflen)
 {
     int ret;
 
@@ -315,24 +342,24 @@ int cnid_find(struct _cnid_db *cdb, const char *name, size_t namelen, void *buff
 /* --------------- */
 char *cnid_resolve(struct _cnid_db *cdb, cnid_t *id, void *buffer, size_t len)
 {
-char *ret;
-
+    char *ret;
     block_signal(cdb->cnid_db_flags);
     ret = cdb->cnid_resolve(cdb, id, buffer, len);
     unblock_signal(cdb->cnid_db_flags);
+
     if (ret && !strcmp(ret, "..")) {
         LOG(log_error, logtype_afpd, "cnid_resolve: name is '..', corrupted db? ");
         ret = NULL;
     }
+
     return ret;
 }
 
 /* --------------- */
-int cnid_update   (struct _cnid_db *cdb, const cnid_t id, const struct stat *st,
-			const cnid_t did, char *name, const size_t len)
+int cnid_update(struct _cnid_db *cdb, const cnid_t id, const struct stat *st,
+                const cnid_t did, char *name, const size_t len)
 {
-int ret;
-
+    int ret;
     block_signal(cdb->cnid_db_flags);
     ret = cdb->cnid_update(cdb, id, st, did, name, len);
     unblock_signal(cdb->cnid_db_flags);
@@ -340,11 +367,11 @@ int ret;
 }
 
 /* --------------- */
-cnid_t cnid_rebuild_add(struct _cnid_db *cdb, const struct stat *st, const cnid_t did,
-                       char *name, const size_t len, cnid_t hint)
+cnid_t cnid_rebuild_add(struct _cnid_db *cdb, const struct stat *st,
+                        const cnid_t did,
+                        char *name, const size_t len, cnid_t hint)
 {
-cnid_t ret;
-
+    cnid_t ret;
     block_signal(cdb->cnid_db_flags);
     ret = cdb->cnid_rebuild_add(cdb, st, did, name, len, hint);
     unblock_signal(cdb->cnid_db_flags);
@@ -355,10 +382,12 @@ cnid_t ret;
 int cnid_wipe(struct _cnid_db *cdb)
 {
     int ret = 0;
-
     block_signal(cdb->cnid_db_flags);
-    if (cdb->cnid_wipe)
+
+    if (cdb->cnid_wipe) {
         ret = cdb->cnid_wipe(cdb);
+    }
+
     unblock_signal(cdb->cnid_db_flags);
     return ret;
 }
