@@ -179,6 +179,11 @@ static int init_prepared_stmt_delete(CNID_sqlite_private *db)
     EC_ZERO_LOG(sqlite3_prepare_v2(db->cnid_sqlite_con, sql, strlen(sql),
                                    &db->cnid_delete_stmt, NULL));
 EC_CLEANUP:
+
+    if (sql) {
+        free(sql);
+    }
+
     EC_EXIT;
 }
 
@@ -493,6 +498,13 @@ cnid_t cnid_sqlite_lookup(struct _cnid_db *cdb, const struct stat *st,
         EC_FAIL;
     }
 
+    if (ntohl(did) < 2) {
+        LOG(log_warning, logtype_cnid,
+            "cnid_sqlite_lookup: not looking up illegal did: %" PRIu32, ntohl(did));
+        errno = CNID_INVALID;
+        EC_FAIL;
+    }
+
     strlcpy(stmt_param_name, name, sizeof(stmt_param_name));
     stmt_param_name_len = len;
     stmt_param_did = ntohl(did);
@@ -912,6 +924,7 @@ cnid_t cnid_sqlite_get(struct _cnid_db *cdb, cnid_t did, const char *name,
     EC_INIT;
     CNID_sqlite_private *db = cdb->cnid_db_private;
     cnid_t id = CNID_INVALID;
+    int sqlite_return;
     LOG(log_maxdebug, logtype_cnid,
         "cnid_sqlite_get(did: %" PRIu32 ", name: \"%s\"): BEGIN",
         ntohl(did), name);
@@ -935,16 +948,21 @@ cnid_t cnid_sqlite_get(struct _cnid_db *cdb, cnid_t did, const char *name,
     EC_ZERO_LOG(sqlite3_bind_text(db->cnid_get_stmt, 1, name, len,
                                   SQLITE_STATIC));
     EC_ZERO_LOG(sqlite3_bind_int64(db->cnid_get_stmt, 2, ntohl(did)));
+    sqlite_return = sqlite3_step(db->cnid_get_stmt);
 
-    if ((sqlite3_step(db->cnid_get_stmt) != SQLITE_ROW)
-            && (sqlite3_errcode(db->cnid_sqlite_con) != 0)) {
+    if (sqlite_return == SQLITE_DONE) {
+        LOG(log_debug, logtype_cnid,
+            "cnid_sqlite_get: name: '%s', did: %u is not in the CNID database",
+            name, ntohl(did));
+    } else if (sqlite_return != SQLITE_ROW) {
         LOG(log_error, logtype_cnid,
             "cnid_sqlite_get: sqlite query error: %s",
             sqlite3_errmsg(db->cnid_sqlite_con));
         EC_FAIL;
+    } else {
+        id = htonl((uint32_t)sqlite3_column_int64(db->cnid_get_stmt, 0));
     }
 
-    id = htonl((uint32_t)sqlite3_column_int64(db->cnid_get_stmt, 0));
 EC_CLEANUP:
     LOG(log_maxdebug, logtype_cnid,
         "cnid_sqlite_get(id: %" PRIu32 ", did: %" PRIu32 ", name: \"%s\"): END",
@@ -1238,8 +1256,14 @@ struct _cnid_db *cnid_sqlite_open(struct cnid_open_args *args)
                 (CNID_sqlite_private *) calloc(1,
                     sizeof(CNID_sqlite_private)));
     cdb->cnid_db_private = db;
-    snprintf(dirpath, sizeof(dirpath), "%sCNID/%s", _PATH_STATEDIR,
-             vol->v_localname);
+
+    if (vol->v_dbpath) {
+        snprintf(dirpath, sizeof(dirpath), "%s", vol->v_dbpath);
+    } else {
+        snprintf(dirpath, sizeof(dirpath), "%sCNID/%s", _PATH_STATEDIR,
+                 vol->v_localname);
+    }
+
     become_root();
 
     if (mkdir(dirpath, 0755) != 0) {
@@ -1328,6 +1352,8 @@ struct _cnid_db *cnid_sqlite_open(struct cnid_open_args *args)
              "VALUES(?, ?, ?, 0)"));
     EC_ZERO_LOG(sqlite3_prepare_v2
                 (db->cnid_sqlite_con, sql, strlen(sql), &transient_stmt, NULL));
+    free(sql);
+    sql = NULL;
     EC_ZERO_LOG(sqlite3_bind_text(transient_stmt,
                                   1, db->cnid_sqlite_voluuid_str,
                                   strlen(db->cnid_sqlite_voluuid_str), SQLITE_STATIC));
@@ -1347,6 +1373,8 @@ struct _cnid_db *cnid_sqlite_open(struct cnid_open_args *args)
 
     sqlite3_reset(transient_stmt);
     sqlite3_clear_bindings(transient_stmt);
+    sqlite3_finalize(transient_stmt);
+    transient_stmt = NULL;
 
     /*
      * Check whether CNID set overflowed before.
@@ -1494,6 +1522,10 @@ EC_CLEANUP:
         free(sql);
     }
 
+    if (dbpath) {
+        bdestroy(dbpath);
+    }
+
     return cdb;
 }
 
