@@ -14,7 +14,7 @@
 
 /*!
  * @file
- * Netatalk utility functions
+ * Netatalk utility functions: unix
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,7 +46,7 @@
 #include <atalk/util.h>
 #include <atalk/vfs.h>
 
-/* close all FDs >= a specified value */
+/*! close all FDs >= a specified value */
 static void closeall(int fd)
 {
     int fdlimit = sysconf(_SC_OPEN_MAX);
@@ -111,11 +111,9 @@ EC_CLEANUP:
 }
 
 /*!
- * Daemonize
+ * @brief Fork, exit parent, setsid(), chdir("/"), close all fds
  *
- * Fork, exit parent, setsid(), chdir("/"), close all fds
- *
- * returns -1 on failure, but you can't do much except exit in that case
+ * @returns -1 on failure, but you can't do much except exit in that case
  * since we may already have forked
  */
 int daemonize(void)
@@ -171,7 +169,7 @@ int daemonize(void)
 
 static uid_t saved_uid = -1;
 
-/*
+/*!
  * seteuid(0) and back, if either fails and panic != 0 we PANIC
  */
 void become_root(void)
@@ -237,14 +235,19 @@ const char *fullpathname(const char *name)
 }
 
 /*!
- * Takes a buffer with a path, strips slashs, returns basename
+ * @brief Takes a buffer with a path, strips slashs, returns basename
  *
  * @param p (rw) path
- *        path may be
- *          "[/][dir/[...]]file"
- *        or
- *          "[/][dir/[...]]dir/[/]"
- *        Result is "file" or "dir"
+ *
+ * path may be
+ * @code
+ *   "[/][dir/[...]]file"
+ * @endcode
+ * or
+ * @code
+ *   "[/][dir/[...]]dir/[/]"
+ * @endcode
+ * Result is "file" or "dir"
  *
  * @returns pointer to basename in path buffer, buffer is possibly modified
  */
@@ -259,13 +262,13 @@ char *stripped_slashes_basename(char *p)
     return strrchr(p, '/') ? strrchr(p, '/') + 1 : p;
 }
 
-/****************************************************************************
- * Find a suitable temporary directory for Netatalk.
+/*!
+ * @brief Find a suitable temporary directory for Netatalk.
+ *
  * Creates a subdirectory for current gid if it doesn't exist.
  * The result should be copied immediately
  * as it may be overwritten by a subsequent call.
- ****************************************************************************/
-
+ */
 const char *tmpdir(void)
 {
     static char netatalk_tmpdir[MAXPATHLEN + 1];
@@ -389,17 +392,18 @@ int ochown(const char *path, uid_t owner, gid_t group, int options)
 }
 
 /*!
- * chmod() wrapper for symlink and ACL handling
+ * @brief chmod() wrapper for symlink and ACL handling
  *
- * @param path       (r) path
- * @param mode       (r) requested mode
- * @param sb         (r) stat() of path or NULL
- * @param option     (r) O_NOFOLLOW | O_NETATALK_ACL
+ * @param[in] path       path
+ * @param[in] mode       requested mode
+ * @param[in] st         stat() of path or NULL
+ * @param[in] options    O_NOFOLLOW | O_NETATALK_ACL
  *
- * Options description:
- * O_NOFOLLOW: don't chmod() symlinks, do nothing, return 0
- * O_NETATALK_ACL: call chmod_acl() instead of chmod()
- * O_IGNORE: ignore chmod() request, directly return 0
+ * Option descriptions:
+ *
+ * - O_NOFOLLOW: don't chmod() symlinks, do nothing, return 0
+ * - O_NETATALK_ACL: call chmod_acl() instead of chmod()
+ * - O_IGNORE: ignore chmod() request, directly return 0
  */
 int ochmod(char *path, mode_t mode, const struct stat *st, int options)
 {
@@ -429,16 +433,17 @@ int ochmod(char *path, mode_t mode, const struct stat *st, int options)
     }
 }
 
-/*
+/*!
  * @brief ostat/fsstatat multiplexer
  *
  * ostatat mulitplexes ostat and fstatat.
  *
- * @param dirfd   (r) -1 gives AT_FDCWD
- * @param path    (r) pathname
- * @param st      (rw) pointer to struct stat
+ * @param[in] dirfd    -1 gives AT_FDCWD
+ * @param[in] path     pathname
+ * @param[in,out] st   pointer to struct stat
+ * @param[in] options  file options
  */
-int ostatat(int dirfd _U_, const char *path, struct stat *st, int options)
+int ostatat(int dirfd, const char *path, struct stat *st, int options)
 {
     if (dirfd == -1) {
         dirfd = AT_FDCWD;
@@ -588,7 +593,7 @@ int gmem(gid_t gid, int ngroups, gid_t *groups)
     return 0;
 }
 
-/*
+/*!
  * realpath() replacement that always allocates storage for returned path
  */
 char *realpath_safe(const char *path)
@@ -628,9 +633,10 @@ char *realpath_safe(const char *path)
 #endif
 }
 
-/**
- * Returns pointer to static buffer with basename of path
- **/
+/*!
+ * @brief safe basename() replacement
+ * @returns pointer to static buffer with basename of path
+ */
 const char *basename_safe(const char *path)
 {
     static char buf[MAXPATHLEN + 1];
@@ -638,10 +644,11 @@ const char *basename_safe(const char *path)
     return basename(buf);
 }
 
-/**
- * extended strtok allows the quoted strings
+/*!
+ * @brief extended strtok allows the quoted strings
+ *
  * modified strtok.c in glibc 2.0.6
- **/
+ */
 char *strtok_quote(char *s, const char *delim)
 {
     static char *olds = NULL;
