@@ -29,6 +29,9 @@
 #include <errno.h>
 #include <netdb.h>
 
+#include <atalk/afp.h>
+#include "dsi.h"
+
 #ifndef SA_ONESHOT
 #define SA_ONESHOT SA_RESETHAND
 #endif
@@ -46,8 +49,6 @@
      | (((x) & 0x00000000000000ffull) << 56))
 #endif	/* bswap_64 */
 
-#include "dsi.h"
-#include "afp.h"
 /* AFP functions */
 #ifndef AFP_CLOSEVOL
 #define AFP_CLOSEVOL     2
@@ -81,28 +82,20 @@
 #define DIRPBIT_UID     10
 #define DIRPBIT_GID     11
 #define DIRPBIT_ACCESS  12
-/* ProDOS Info /UTF8 name */
-#define DIRPBIT_PDINFO  13
+#define DIRPBIT_PDINFO  13         /*!< ProDOS Info /UTF8 name */
 #define DIRPBIT_UNIXPR  15
 
 /* directory attribute bits (see file.h for other bits) */
-/* shared point */
-#define ATTRBIT_EXPFOLDER   (1 << 1)
-/* mounted share point by non-admin */
-#define ATTRBIT_MOUNTED     (1 << 3)
-/* folder in a shared area */
-#define ATTRBIT_INEXPFOLDER (1 << 4)
+#define ATTRBIT_EXPFOLDER   (1 << 1) /*!< shared point */
+#define ATTRBIT_MOUNTED     (1 << 3) /*!< mounted share point by non-admin */
+#define ATTRBIT_INEXPFOLDER (1 << 4) /*!< folder in a shared area */
 
-/* is a directory */
-#define FILDIRBIT_ISDIR        (1 << 7)
-/* is a file */
-#define FILDIRBIT_ISFILE       (0)
+#define FILDIRBIT_ISDIR        (1 << 7) /*!< is a directory */
+#define FILDIRBIT_ISFILE       (0)      /*!< is a file */
 
 /* reserved directory id's */
-/* parent directory of root */
-#define DIRDID_ROOT_PARENT    htonl(1)
-/* root directory */
-#define DIRDID_ROOT           htonl(2)
+#define DIRDID_ROOT_PARENT    htonl(1)  /*!< parent directory of root */
+#define DIRDID_ROOT           htonl(2)  /*!< root directory */
 
 /* ----------------------------- */
 /* from etc/afpd/file.h volume attributes */
@@ -118,36 +111,23 @@
 #define FILPBIT_DFLEN    9
 #define FILPBIT_RFLEN    10
 #define FILPBIT_EXTDFLEN 11
-/* ProDOS Info/ UTF8 name */
-#define FILPBIT_PDINFO   13
+#define FILPBIT_PDINFO   13    /*!< ProDOS Info/ UTF8 name */
 #define FILPBIT_EXTRFLEN 14
 #define FILPBIT_UNIXPR   15
 
 /* attribute bits. d = directory attribute bit as well. */
-/* invisible d */
-#define ATTRBIT_INVISIBLE (1<<0)
-/* multiuser */
-#define ATTRBIT_MULTIUSER (1<<1)
-/* system d */
-#define ATTRBIT_SYSTEM    (1<<2)
-/* data fork already open */
-#define ATTRBIT_DOPEN     (1<<3)
-/* resource fork already open */
-#define ATTRBIT_ROPEN     (1<<4)
-/* shared area d */
-#define ATTRBIT_SHARED    (1<<4)
-/* write inhibit(v2)/read-only(v1) bit */
-#define ATTRBIT_NOWRITE   (1<<5)
-/* backup needed d */
-#define ATTRBIT_BACKUP    (1<<6)
-/* rename inhibit d */
-#define ATTRBIT_NORENAME  (1<<7)
-/* delete inhibit d */
-#define ATTRBIT_NODELETE  (1<<8)
-/* copy protect */
-#define ATTRBIT_NOCOPY    (1<<10)
-/* set/clear bits d */
-#define ATTRBIT_SETCLR    (1<<15)
+#define ATTRBIT_INVISIBLE (1<<0)  /*!< invisible (d) */
+#define ATTRBIT_MULTIUSER (1<<1)  /*!< multiuser */
+#define ATTRBIT_SYSTEM    (1<<2)  /*!< system (d) */
+#define ATTRBIT_DOPEN     (1<<3)  /*!< data fork already open */
+#define ATTRBIT_ROPEN     (1<<4)  /*!< resource fork already open */
+#define ATTRBIT_SHARED    (1<<4)  /*!< shared area (d) */
+#define ATTRBIT_NOWRITE   (1<<5)  /*!< write inhibit(v2)/read-only(v1) bit */
+#define ATTRBIT_BACKUP    (1<<6)  /*!< backup needed (d) */
+#define ATTRBIT_NORENAME  (1<<7)  /*!< rename inhibit (d) */
+#define ATTRBIT_NODELETE  (1<<8)  /*!< delete inhibit (d) */
+#define ATTRBIT_NOCOPY    (1<<10) /*!< copy protect */
+#define ATTRBIT_SETCLR    (1<<15) /*!< set/clear bits (d) */
 
 /* ----------------------------- */
 /* from etc/afpd/volume.h volume attributes */
@@ -176,8 +156,7 @@
 /* handle > 4GB volumes */
 #define VOLPBIT_XBFREE  9
 #define VOLPBIT_XBTOTAL 10
-/* block size */
-#define VOLPBIT_BSIZE   11
+#define VOLPBIT_BSIZE   11        /*!< block size */
 /* ----------------------------- */
 
 /* from etc/afpd/fork.h */
@@ -217,6 +196,8 @@ typedef struct CONN {
     int afp_version;
 } CONN;
 
+extern CONN *Conn, *Conn2;
+
 #define min(a,b)  ((a) < (b) ? (a) : (b))
 
 #define PASSWDLEN 8
@@ -237,8 +218,7 @@ int my_dsi_data_receive(DSI *x);
 /* Files and directories */
 struct afp_filedir_parms {
     int isdir;
-    /* Parameters already taken from svr */
-    uint16_t bitmap;
+    uint16_t bitmap;  /*!< Parameters already taken from svr */
     uint16_t attr;
     uint16_t vid;
     uint32_t pdid;
@@ -249,12 +229,9 @@ struct afp_filedir_parms {
     uint64_t ext_rflen;
     uint16_t offcnt;
     uint32_t uid, gid;
-    /* FIXME what if mode_t != uint32_t */
-    uint32_t unix_priv;
-    /* Access bits */
-    uint8_t access[4];
-    /* ProDOS info... */
-    uint8_t pdinfo[6];
+    uint32_t unix_priv;   /* FIXME what if mode_t != uint32_t */
+    uint8_t access[4];    /*!< Access bits */
+    uint8_t pdinfo[6];    /*!< ProDOS info... */
     /* FIXME: Finder info ! */
     char finder_info[32];
     int  name_type;
@@ -279,13 +256,14 @@ struct afp_volume_parms {
 void afp_volume_unpack(struct afp_volume_parms *parms, unsigned char *b,
                        uint16_t rbitmap);
 
-void afp_filedir_unpack(struct afp_filedir_parms *filedir, unsigned char *b,
+void afp_filedir_unpack(struct afp_filedir_parms *filedir,
+                        const unsigned char *b,
                         uint16_t rfbitmap, uint16_t rdbitmap);
 int afp_filedir_pack(unsigned char *b, struct afp_filedir_parms *filedir,
                      uint16_t rfbitmap, uint16_t rdbitmap);
 
 /*
- afpcli.c
+ afpclient.c
 */
 int OpenClientSocket(char *host, int port);
 int CloseClientSocket(int fd);
@@ -297,6 +275,7 @@ int my_dsi_stream_receive(DSI *dsi, void *buf, const size_t ilength,
 size_t my_dsi_stream_write(DSI *dsi, void *data, const size_t length);
 int my_dsi_stream_send(DSI *dsi, void *buf, size_t length);
 uint16_t my_dsi_cmd_nwriterply_async(CONN *conn, uint64_t n);
+void dump_header(DSI *dsi);
 
 unsigned int DSIOpenSession(CONN *conn);
 unsigned int DSIGetStatus(CONN *conn);
@@ -400,8 +379,39 @@ unsigned int AFPCatSearchExt(CONN *conn, uint16_t vol, uint32_t  nbe, char *pos,
 unsigned int AFPSetForkParam(CONN *conn, uint16_t fork,  uint16_t bitmap,
                              off_t size);
 
+/* FileSecurity bitmap values */
+#define kFileSec_UUID        (1 << 0)
+#define kFileSec_GRPUUID     (1 << 1)
+#define kFileSec_ACL         (1 << 2)
+#define kFileSec_REMOVEACL   (1 << 3)
+#define kFileSec_Inherit     (1 << 4)
+
+/* Darwin ACE structure (24 bytes total) */
+typedef struct darwin_ace {
+    unsigned char darwin_ace_uuid[16];  /* 16 bytes UUID */
+    uint32_t darwin_ace_flags;          /* 4 bytes flags (network byte order) */
+    uint32_t darwin_ace_rights;         /* 4 bytes rights (network byte order) */
+} __attribute__((packed)) darwin_ace_t;
+
+/* Darwin ACE flags - Must match server definitions in etc/afpd/acls.h
+ * These are bit flags that can be combined with inheritance flags
+ * PERMIT/DENY occupy bits 0-1 of the flags field
+ */
+#define DARWIN_ACE_FLAGS_PERMIT         0x00000001  /* Bit 0: ALLOW access */
+#define DARWIN_ACE_FLAGS_DENY           0x00000002  /* Bit 1: DENY access */
+#define DARWIN_ACE_FLAGS_FILE_INHERIT   0x00000020  /* Bit 5: Inherit to files */
+#define DARWIN_ACE_FLAGS_DIRECTORY_INHERIT 0x00000040  /* Bit 6: Inherit to dirs */
+#define DARWIN_ACE_FLAGS_ONLY_INHERIT   0x00000100  /* Bit 8: Inherit only */
+
+/* Darwin ACE rights (simplified subset) */
+#define DARWIN_ACE_READ_DATA            0x00000002
+#define DARWIN_ACE_WRITE_DATA           0x00000004
+#define DARWIN_ACE_EXECUTE              0x00000008
+
 unsigned int AFPGetACL(CONN *conn, uint16_t vol, int did, uint16_t bitmap,
                        char *name);
+unsigned int AFPSetACL(CONN *conn, uint16_t vol, int did, uint16_t bitmap,
+                       char *name, uint32_t ace_count, darwin_ace_t *aces);
 unsigned int AFPListExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap,
                             int maxsize, char *pathname);
 unsigned int AFPGetExtAttr(CONN *conn, uint16_t vol, int did, uint16_t bitmap,
