@@ -1,7 +1,10 @@
-#include "specs.h"
-
 #include <getopt.h>
 
+#include "afpclient.h"
+#include "afpcmd.h"
+#include "afphelper.h"
+#include "testhelper.h"
+
 uint16_t VolID;
 
 CONN *Conn;
@@ -31,6 +34,7 @@ char    *Path;
 int     Version = 34;
 int     List = 0;
 int     Mac = 0;
+int     EmptyVol = 0;
 char    *Test;
 static char  *vers = "AFP3.4";
 
